import { ChatStoreInitialProps } from "./ChatStore";
import { GlobalStoreInitialProps } from "./GlobalStore";
import { SearchStoreInitialProps } from "./SearchStore";
import { createStore } from "@stencil/store";
// biome-ignore lint/suspicious/noExplicitAny: Any is acceptable here
const storesMapInitialProps = {
    global: GlobalStoreInitialProps,
    search: SearchStoreInitialProps,
    chat: ChatStoreInitialProps,
};
/**
 * Holds the global references for all stores in Orama Ui.
 *
 */
const storesReferencesMap = new Map();
/**
 * Access storeSReferenceMap and return the initialized store. Throw exception if either parent or store does not exist
 *
 * @param parentComponentId
 * @param storeName
 * @returns
 */
const getParentComponentStore = (parentComponentId, storeName) => {
    const parentStores = storesReferencesMap.get(parentComponentId);
    if (!parentStores) {
        throw new Error('Invalid parent component Id');
    }
    const store = parentStores[storeName];
    if (!store) {
        throw new Error('Store not initialized');
    }
    return store;
};
export const initStore = (storeName, parentComponentId) => {
    const initialProps = storesMapInitialProps[storeName];
    if (!initialProps) {
        throw new Error('Invalid store name');
    }
    const store = createStore(initialProps);
    if (storesReferencesMap.has(parentComponentId)) {
        const currentStores = storesReferencesMap.get(parentComponentId);
        currentStores[storeName] = store;
    }
    else {
        storesReferencesMap.set(parentComponentId, { [storeName]: store });
    }
    return store;
};
export const removeAllStores = (parentComponentId) => {
    storesReferencesMap.delete(parentComponentId);
};
export function getStore(storeName, element) {
    const externalComponent = getExternalParentComponentHTMLElement(element);
    if (!externalComponent) {
        throw new Error('Failed to get store');
    }
    return getParentComponentStore(externalComponent.id, storeName);
}
const EXTERNAL_COMPONENT_TAG_LIST = ['orama-search-box', 'orama-chat-box'];
function getExternalParentComponentHTMLElement(element) {
    var _a;
    let currentNode = element;
    currentNode.parentNode;
    while (true) {
        if (!currentNode) {
            return null;
        }
        if (currentNode instanceof ShadowRoot) {
            const host = currentNode.host;
            if (EXTERNAL_COMPONENT_TAG_LIST.includes(host.tagName.toLowerCase())) {
                return host;
            }
            currentNode = host;
        }
        else {
            currentNode = (_a = currentNode.parentNode) !== null && _a !== void 0 ? _a : null;
        }
    }
}
//# sourceMappingURL=ParentComponentStoreManager.js.map
