import { h } from "@stencil/core";
import { getNonExplicitAttributes } from "../../../utils/utils";
/**
 * The orama-button component is used to render a button or anchor element looking like a button.
 */
export class OramaButton {
    constructor() {
        this.as = 'button';
        this.variant = 'primary';
        this.size = 'medium';
    }
    render() {
        const Tag = this.as;
        const declaredProps = ['as', 'class', 'variant'];
        const buttonProps = getNonExplicitAttributes(this.el, declaredProps);
        const buttonClass = `button button--${this.variant} button--${this.size} ${this.class || ''}`;
        return (h(Tag, Object.assign({ key: 'af470570a767787e5e85ec5c0ecc4cfb66e5b142', class: buttonClass }, buttonProps, { disabled: this.disabled }), h("span", { key: '483fb6a261decf60053ec78726912e11ae271e74', class: "button__label" }, h("slot", { key: '3d00cc8a7fe04471095f87b9989eebf38c79764a', name: "adorment-start" }), this.withTooltip && h("span", { key: 'bdda78c3dc2e39b53254a5506dcfb53bffdb9ed3', class: "button__tooltip" }, this.withTooltip), h("slot", { key: '6582b9e1c0481f18ac91844b0f09ff09b9fa1fbf' })), h("slot", { key: '31d3bcf229c837809ccf3ba74986a179fe028c87', name: "adorment-end" })));
    }
    static get is() { return "orama-button"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-button.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-button.css"]
        };
    }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "attribute": "as",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['as']",
                    "resolved": "\"a\" | \"button\"",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-button/orama-button.tsx",
                            "id": "src/components/internal/orama-button/orama-button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'button'"
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['variant']",
                    "resolved": "\"icon\" | \"primary\" | \"secondary\"",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-button/orama-button.tsx",
                            "id": "src/components/internal/orama-button/orama-button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'primary'"
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "'small' | 'medium' | 'large'",
                    "resolved": "\"large\" | \"medium\" | \"small\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'medium'"
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "ButtonProps['type']",
                    "resolved": "\"button\" | \"reset\" | \"submit\"",
                    "references": {
                        "ButtonProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-button/orama-button.tsx",
                            "id": "src/components/internal/orama-button/orama-button.tsx::ButtonProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "withTooltip": {
                "type": "string",
                "attribute": "with-tooltip",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=orama-button.js.map
