import { h } from "@stencil/core";
import "@phosphor-icons/webcomponents/dist/icons/PhCaretLeft.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhCaretRight.mjs";
const SOURCE_BOX_OFFSET = 0;
export class OramaSources {
    constructor() {
        this.sourceBaseURL = '';
        this.linksTarget = '_blank';
        this.linksRel = 'noopener noreferrer';
        this.isCarouselScrollAtEnd = false;
        this.isCarouselScrollAtStart = false;
        this.handleCarouselScroll = () => {
            this.computeCarouselArrowsVisibility();
        };
        this.handleItemClick = (originalOnClickEvent, item) => {
            const answerSourceClick = this.answerSourceClick.emit({ source: item });
            if (answerSourceClick.defaultPrevented) {
                originalOnClickEvent.preventDefault();
                return;
            }
            if (!(item === null || item === void 0 ? void 0 : item.path)) {
                throw new Error('No path found');
            }
        };
        this.resizeObserver = new ResizeObserver(() => {
            this.computeCarouselArrowsVisibility();
        });
    }
    // TODO: Move this to utils
    buildUrl(path) {
        if (!path) {
            return '#';
        }
        if (this.sourceBaseURL) {
            // Remove trailing slashes from the base URL
            const sanitizedBaseUrl = this.sourceBaseURL.replace(/\/+$/, '');
            // Remove leading slashes from the path
            const sanitizedPath = path.replace(/^\/+/, '');
            // Concatenate the base URL with the path
            return `${sanitizedBaseUrl}/${sanitizedPath}`;
        }
        return path;
    }
    getNextItemCarousel(container, items) {
        for (let i = 0; i < items.length; i++) {
            const item = items[i];
            const itemRect = item.getBoundingClientRect();
            const containerRect = container.getBoundingClientRect();
            // Check if item is totally or partially visible
            if (itemRect.right - SOURCE_BOX_OFFSET > containerRect.right) {
                return item;
            }
        }
        return null;
    }
    getPreviousItemCarousel(container, items) {
        var _a;
        for (let i = 0; i < items.length; i++) {
            const item = items[i];
            const itemRect = item.getBoundingClientRect();
            const containerRect = container.getBoundingClientRect();
            // Check if the item is totally visible
            if (itemRect.left + SOURCE_BOX_OFFSET >= containerRect.left &&
                itemRect.right - SOURCE_BOX_OFFSET <= containerRect.right) {
                return (_a = items[i - 1]) !== null && _a !== void 0 ? _a : null;
                // biome-ignore lint/style/noUselessElse: better with to make the intention clear
            }
            else if (itemRect.left - SOURCE_BOX_OFFSET < containerRect.right &&
                itemRect.right - SOURCE_BOX_OFFSET > containerRect.right) {
                return item;
            }
        }
        return null;
    }
    handleCarouselMove(direction) {
        const carousel = this.carouselSourceRef;
        if (!carousel) {
            return;
        }
        const items = carousel.getElementsByClassName('source-inner-wrapper');
        if (direction === 'forward') {
            const nextItemCarousel = this.getNextItemCarousel(carousel, items);
            if (nextItemCarousel) {
                nextItemCarousel.scrollIntoView({
                    behavior: 'smooth',
                    inline: 'end',
                    block: 'nearest',
                });
            }
        }
        else {
            const previousItemCarousel = this.getPreviousItemCarousel(carousel, items);
            if (previousItemCarousel) {
                previousItemCarousel.scrollIntoView({
                    behavior: 'smooth',
                    inline: 'start',
                    block: 'nearest',
                });
            }
        }
    }
    computeCarouselArrowsVisibility() {
        const carousel = this.carouselSourceRef;
        if (!carousel) {
            return;
        }
        const items = carousel.getElementsByClassName('source-inner-wrapper');
        this.isCarouselScrollAtEnd = !this.getNextItemCarousel(carousel, items);
        this.isCarouselScrollAtStart = !this.getPreviousItemCarousel(carousel, items);
    }
    componentDidLoad() {
        var _a;
        (_a = this.carouselSourceRef) === null || _a === void 0 ? void 0 : _a.addEventListener('scroll', this.handleCarouselScroll);
        this.computeCarouselArrowsVisibility();
        if (this.carouselSourceRef) {
            this.resizeObserver.observe(this.carouselSourceRef);
        }
    }
    disconnectedCallback() {
        var _a;
        (_a = this.carouselSourceRef) === null || _a === void 0 ? void 0 : _a.removeEventListener('scroll', this.handleCarouselScroll);
        this.resizeObserver.disconnect();
    }
    hasHorizontalOverflow(element) {
        if (!element) {
            return false;
        }
        return element.scrollWidth > element.clientWidth;
    }
    render() {
        var _a;
        if (!((_a = this.sources) === null || _a === void 0 ? void 0 : _a.length)) {
            return;
        }
        return (h("host", null, h("div", { class: {
                'sources-outer-wrapper': true,
                'oveflow-decorator': this.hasHorizontalOverflow(this.carouselSourceRef),
            } }, h("h2", { class: "sr-only" }, "Sources"), h("button", { class: { 'carousel-arrow carousel-arrow--prev': true, hidden: this.isCarouselScrollAtStart }, onClick: () => this.handleCarouselMove('backwards'), type: "button" }, h("ph-caret-left", null)), h("button", { class: { 'carousel-arrow carousel-arrow--next': true, hidden: this.isCarouselScrollAtEnd }, onClick: () => this.handleCarouselMove('forward'), type: "button" }, h("ph-caret-right", null)), h("div", { class: "sources-wrapper", ref: (el) => {
                this.carouselSourceRef = el;
            } }, this.sources.map((source, index) => {
            const showSources = (!!source.title && !!source.path) || (!!source.description && !!source.path);
            if (!showSources)
                return;
            return (h("div", { class: "source-inner-wrapper",
                // biome-ignore lint/suspicious/noArrayIndexKey: we do not have id for sources
                key: `source-${index}`, style: {
                    position: 'relative',
                    display: 'flex',
                } }, h("a", { href: this.buildUrl(source.path), class: "source", target: this.linksTarget, rel: this.linksRel, id: `source-${index}`, onClick: (onClickEvent) => this.handleItemClick(onClickEvent, source) }, h("orama-text", { as: "h3", styledAs: "span", class: "source-title" }, source.title), h("orama-text", { as: "p", styledAs: "span", class: "source-subtitle", variant: "tertiary" }, source.description))));
        })))));
    }
    static get is() { return "orama-sources"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-sources.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-sources.css"]
        };
    }
    static get properties() {
        return {
            "sources": {
                "type": "any",
                "attribute": "sources",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "sourceBaseURL": {
                "type": "string",
                "attribute": "source-base-u-r-l",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "linksTarget": {
                "type": "string",
                "attribute": "links-target",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'_blank'"
            },
            "linksRel": {
                "type": "string",
                "attribute": "links-rel",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'noopener noreferrer'"
            }
        };
    }
    static get states() {
        return {
            "isCarouselScrollAtEnd": {},
            "isCarouselScrollAtStart": {}
        };
    }
    static get events() {
        return [{
                "method": "answerSourceClick",
                "name": "answerSourceClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "OnAnswerSourceClickCallbackProps",
                    "resolved": "{ source: SearchResult; }",
                    "references": {
                        "OnAnswerSourceClickCallbackProps": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::OnAnswerSourceClickCallbackProps"
                        }
                    }
                }
            }];
    }
}
//# sourceMappingURL=orama-sources.js.map
