var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
    else
        for (var i = decorators.length - 1; i >= 0; i--)
            if (d = decorators[i])
                r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { Fragment, Host, h } from "@stencil/core";
import { TAnswerStatus, } from "../../../types/index";
import "@phosphor-icons/webcomponents/dist/icons/PhPaperPlaneTilt.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhStopCircle.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhArrowDown.mjs";
import { Store } from "../../../StoreDecorator";
import { getText as getTextUtil } from "../../../utils/textDictionary";
const BOTTOM_THRESHOLD = 1;
export class OramaChat {
    constructor() {
        this.placeholder = 'Ask me anything';
        this.sourceBaseUrl = '';
        this.showClearChat = true;
        this.focusInput = false;
        this.disclaimer = 'Orama can make mistakes. Please verify the information.';
        this.inputValue = '';
        this.showGoToBottomButton = false;
        this.triggerSendQuestion = (question, relatedQueries) => {
            if (this.chatStore.state.chatService === null) {
                throw new Error('Chat Service is not initialized');
            }
            this.startConversation.emit({ userPrompt: question, systemPrompts: this.systemPrompts });
            this.chatStore.state.chatService.sendQuestion(question, relatedQueries, this.systemPrompts, {
                onAnswerGeneratedCallback: (params) => this.answerGenerated.emit(params),
            });
        };
        this.isScrolling = false;
        this.prevScrollTop = 0;
        this.scrollTarget = 0;
        this.pendingNewInteractionSideEffects = false;
        this.lockScrollOnBottom = false;
        this.handleFocus = () => {
            if (this.focusInput) {
                const texteareaEl = this.textareaRef.querySelector('textarea');
                if (!texteareaEl)
                    return;
                // requestAnimationFrame used to ensure that the focus is set after the textarea is fully rendered
                requestAnimationFrame(() => {
                    texteareaEl.focus();
                });
            }
        };
        this.calculateIsScrollOnBottom = () => {
            const scrollableHeight = this.messagesContainerRef.scrollHeight - this.messagesContainerRef.clientHeight;
            return this.messagesContainerRef.scrollTop + BOTTOM_THRESHOLD >= scrollableHeight;
        };
        this.scrollToBottom = (options = { animated: true, onScrollDone: () => { } }) => {
            if (!this.messagesContainerRef) {
                return;
            }
            if (!options.animated) {
                this.messagesContainerRef.scrollTop = this.messagesContainerRef.scrollHeight;
                options.onScrollDone();
                return;
            }
            this.isScrolling = true;
            const startTime = performance.now();
            const startPosition = this.messagesContainerRef.scrollTop;
            const duration = 300; // Custom duration in milliseconds
            const animateScroll = (currentTime) => {
                if (!this.messagesContainerRef || !this.isScrolling) {
                    return;
                }
                const scrollTarget = this.messagesContainerRef.scrollHeight - this.messagesContainerRef.clientHeight;
                const elapsedTime = currentTime - startTime;
                const scrollProgress = Math.min(1, elapsedTime / duration);
                const easeFunction = this.easeInOutQuad(scrollProgress);
                const scrollTo = startPosition + (scrollTarget - startPosition) * easeFunction;
                this.messagesContainerRef.scrollTo(0, scrollTo);
                if (elapsedTime < duration) {
                    requestAnimationFrame(animateScroll);
                }
                else {
                    this.isScrolling = false;
                    options.onScrollDone();
                }
            };
            requestAnimationFrame(animateScroll);
        };
        // Easing function for smooth scroll animation
        this.easeInOutQuad = (t) => {
            return t < 0.5 ? 2 * t * t : -1 + (4 - 2 * t) * t;
        };
        this.recalculateGoBoToBottomButton = () => {
            const isContainerOverflowing = this.calculateIsContainerOverflowing();
            if (!isContainerOverflowing) {
                this.showGoToBottomButton = false;
                return;
            }
            this.showGoToBottomButton = !this.calculateIsScrollOnBottom();
        };
        this.handleWheel = (e) => {
            const isContainerOverflowing = this.calculateIsContainerOverflowing();
            if (!isContainerOverflowing) {
                this.lockScrollOnBottom = false;
                this.showGoToBottomButton = false;
                return;
            }
            // Get the current scroll position
            const currentScrollTop = this.messagesContainerRef.scrollTop;
            this.showGoToBottomButton = !this.calculateIsScrollOnBottom();
            this.lockScrollOnBottom = !this.showGoToBottomButton;
            if (!this.showGoToBottomButton) {
                this.isScrolling = false;
            }
            // Update the previous scroll position
            this.prevScrollTop = currentScrollTop;
        };
        this.setSources = () => {
            this.chatStore.state.sourceBaseURL = this.sourceBaseUrl;
            this.chatStore.state.sourcesMap = this.sourcesMap;
            this.chatStore.state.linksTarget = this.linksTarget;
            this.chatStore.state.linksRel = this.linksRel;
        };
        this.handleSubmit = (e) => {
            e.preventDefault();
            if (this.chatStore.state.chatService === null) {
                throw new Error('Chat Service is not initialized');
            }
            this.startConversation.emit({ userPrompt: this.inputValue, systemPrompts: this.systemPrompts });
            this.chatStore.state.chatService.sendQuestion(this.inputValue, this.relatedQueries, this.systemPrompts, {
                onAnswerGeneratedCallback: (params) => this.answerGenerated.emit(params),
            });
            this.chatStore.state.prompt = this.inputValue;
            this.inputValue = '';
        };
        this.handleAbortAnswerClick = () => {
            this.chatStore.state.chatService.abortAnswer();
        };
        this.handleSuggestionClick = (suggestion, relatedQueries) => {
            if (this.chatStore.state.chatService === null) {
                throw new Error('Chat Service is not initialized');
            }
            this.startConversation.emit({ userPrompt: suggestion, systemPrompts: this.systemPrompts });
            this.chatStore.state.chatService.sendQuestion(suggestion, relatedQueries, undefined, {
                onAnswerGeneratedCallback: (params) => this.answerGenerated.emit(params),
            });
            this.inputValue = '';
        };
        this.handleClearChat = () => {
            this.chatStore.state.chatService.resetChat();
            this.clearChat.emit();
        };
        this.calculateIsContainerOverflowing = () => {
            if (!this.messagesContainerRef) {
                return false;
            }
            return this.messagesContainerRef.scrollHeight > this.messagesContainerRef.clientHeight;
        };
    }
    handleSourceItemClick(event) {
        // console.log(`Source item clicked: ${event.detail.title}`, event.detail)
    }
    handleDefaultTermChange() {
        var _a;
        if (this.defaultTerm) {
            (_a = this.chatStore.state.chatService) === null || _a === void 0 ? void 0 : _a.sendQuestion(this.defaultTerm, this.relatedQueries, this.systemPrompts, {
                onAnswerGeneratedCallback: (params) => this.answerGenerated.emit(params),
            });
        }
    }
    focusInputWatcher() {
        this.handleFocus();
    }
    promptWatcher(newValue, oldValue) {
        if (newValue !== oldValue) {
            this.triggerSendQuestion(newValue, this.relatedQueries);
            this.chatStore.state.prompt = newValue;
        }
    }
    handleTextDictionaryChange() {
        var _a, _b;
        // If dictionary has a chatPlaceholder, update the placeholder prop
        if ((_a = this.dictionary) === null || _a === void 0 ? void 0 : _a.chatPlaceholder) {
            this.placeholder = this.dictionary.chatPlaceholder;
        }
        // If dictionary has a disclaimer, update the disclaimer prop
        if ((_b = this.dictionary) === null || _b === void 0 ? void 0 : _b.disclaimer) {
            this.disclaimer = this.dictionary.disclaimer;
        }
        // Log the current values for debugging
        console.log('Updated from dictionary:', {
            placeholder: this.placeholder,
            disclaimer: this.disclaimer,
            dictionary: this.dictionary,
        });
    }
    componentWillLoad() {
        var _a;
        // Initialize placeholder and disclaimer from dictionary if available
        this.handleTextDictionaryChange();
        // Ensure the disclaimer has a default value if not set
        if (!this.disclaimer && ((_a = this.dictionary) === null || _a === void 0 ? void 0 : _a.disclaimer)) {
            this.disclaimer = this.dictionary.disclaimer;
        }
        else if (!this.disclaimer) {
            this.disclaimer = 'Orama can make mistakes. Please verify the information.';
        }
        this.chatStore.on('set', (prop, newInteractions, oldInteractions) => {
            if (prop !== 'interactions') {
                return;
            }
            if ((oldInteractions === null || oldInteractions === void 0 ? void 0 : oldInteractions.length) < (newInteractions === null || newInteractions === void 0 ? void 0 : newInteractions.length)) {
                this.lockScrollOnBottom = false;
                this.pendingNewInteractionSideEffects = true;
            }
        });
    }
    /**
     * Gets the text for a specific key from the dictionary prop.
     * Prioritizes direct props (placeholder) for backward compatibility,
     * then falls back to the dictionary prop, and finally to the defaultTextDictionary.
     *
     * @param key - The key to get the text for
     * @returns The text for the specified key
     */
    getText(key) {
        // Create a map of direct props for backward compatibility
        const directProps = {
            chatPlaceholder: this.placeholder,
        };
        // If the key exists in directProps and its value is defined, return its value
        const directValue = directProps[key];
        if (directValue !== undefined) {
            return directValue;
        }
        // Otherwise, try to get the text from the dictionary prop or fall back to the defaultTextDictionary
        return getTextUtil(key, this.dictionary);
    }
    componentDidLoad() {
        var _a;
        this.messagesContainerRef.addEventListener('wheel', this.handleWheel);
        this.setSources();
        this.handleFocus();
        if (this.prompt && ((_a = this.chatStore.state) === null || _a === void 0 ? void 0 : _a.prompt) !== this.prompt) {
            this.triggerSendQuestion(this.prompt);
            this.chatStore.state.prompt = this.prompt;
        }
        this.scrollableContainerResizeObserver = new ResizeObserver(() => {
            this.recalculateGoBoToBottomButton();
        });
        this.scrollableContainerResizeObserver.observe(this.messagesContainerRef);
        this.nonScrollableContainerResizeObserver = new ResizeObserver(() => {
            if (this.pendingNewInteractionSideEffects) {
                this.pendingNewInteractionSideEffects = false;
                this.lockScrollOnBottom = false;
                this.scrollToBottom({
                    animated: true,
                    onScrollDone: () => {
                        this.recalculateGoBoToBottomButton();
                    },
                });
                return;
            }
            if (this.lockScrollOnBottom && !this.isScrolling) {
                this.scrollToBottom({
                    animated: false,
                    onScrollDone: () => {
                        this.recalculateGoBoToBottomButton();
                    },
                });
            }
            this.recalculateGoBoToBottomButton();
        });
        this.nonScrollableContainerResizeObserver.observe(this.nonScrollableMessagesContainerRef);
    }
    disconnectedCallback() {
        var _a, _b, _c;
        (_a = this.messagesContainerRef) === null || _a === void 0 ? void 0 : _a.removeEventListener('wheel', this.handleWheel);
        (_b = this.scrollableContainerResizeObserver) === null || _b === void 0 ? void 0 : _b.disconnect();
        (_c = this.nonScrollableContainerResizeObserver) === null || _c === void 0 ? void 0 : _c.disconnect();
        if (this.clearChatOnDisconnect) {
            this.chatStore.state.interactions = [];
        }
    }
    render() {
        var _a, _b, _c;
        const lastInteraction = (_a = this.chatStore.state.interactions) === null || _a === void 0 ? void 0 : _a[this.chatStore.state.interactions.length - 1];
        const lastInteractionStatus = lastInteraction === null || lastInteraction === void 0 ? void 0 : lastInteraction.status;
        const hasInteractions = ((_b = this.chatStore.state.interactions) === null || _b === void 0 ? void 0 : _b.length) > 0;
        // ? Question: Maybe should be a orama-button variant?
        return (h(Host, { key: '36ca94edc3d8586e453df83598c1e3775b951ef2' }, this.showClearChat && hasInteractions && (h("div", { key: 'a9744683546e7ffe873ab8dcc40f9ebab0682314', class: "header" }, h("button", { key: 'd4caf76a5cd486dc3834cc1637126d5991b90d64', type: "button", onClick: this.handleClearChat }, h("ph-arrow-clockwise", { key: '26b63e43c56cb45a16aca0d05bcdf9ffa116ef54', weight: "fill", size: "14" }), " ", this.getText('clearChat')))), h("div", { key: '58262eaaccdcfe4ff7f6d2ddc4a97cad0a23273c', class: 'messages-container-wrapper-non-scrollable' }, h("div", { key: '7cdb715fba7e995b05e168dec24ed295c012214b', class: `messages-container-wrapper ${!hasInteractions ? 'isEmpty' : ''}`, ref: (ref) => (this.messagesContainerRef = ref) }, h("div", { key: '57b5a616efe3a6a292a872e66449a580f3a2b9b9', ref: (ref) => (this.nonScrollableMessagesContainerRef = ref) }, hasInteractions ? (h("orama-chat-messages-container", { interactions: this.chatStore.state.interactions, chatMarkdownLinkTitle: this.chatMarkdownLinkTitle, chatMarkdownLinkHref: this.chatMarkdownLinkHref })) : null, !hasInteractions ? (h(Fragment, null, h("slot", { name: "chat-empty-state" }), !!((_c = this.suggestions) === null || _c === void 0 ? void 0 : _c.length) && (h("div", { class: "suggestions-wrapper" }, h("orama-suggestions", { suggestions: this.suggestions, suggestionClicked: this.handleSuggestionClick }))))) : null)), this.showGoToBottomButton && (h("button", { key: '782413cd8d3626a66502b48c1edf0268b0beec0b', class: "lock-scroll-on-bottom-button-wrapper", type: "button", onClick: () => {
                this.lockScrollOnBottom = true;
                this.scrollToBottom({ animated: true, onScrollDone: () => this.recalculateGoBoToBottomButton() });
            } }, h("ph-arrow-down", { key: 'f69a1dc562d5b3497d7cb07554fab7a935f4ba09', size: '18px' })))), h("div", { key: 'abd186afafe6f1bc2e0017df0f8e76da9733de3f', class: "chat-form-wrapper" }, h("form", { key: '7a4dce2634157f1910de57f15e9d4e9b47dd1c4c', onSubmit: this.handleSubmit }, h("div", { key: '4713aaa3164d81f5af9fb6ed4f6f072920f0a9ba', class: "chat-input" }, h("orama-textarea", { key: '2cf9cb0e628e397349938c3ab51b0000276fc387', ref: (ref) => (this.textareaRef = ref), autoFocus: this.focusInput, maxRows: 4, value: this.inputValue, onKeyDown: (e) => {
                if (e.key === 'Enter' && !e.shiftKey) {
                    this.handleSubmit(e);
                    e.preventDefault();
                }
            }, onInput: (e) => {
                this.inputValue = e.target.value;
            }, placeholder: this.placeholder }, h("div", { key: '7f8cb7a328aaec75f673aa9a733fbe39e16bfd02', slot: "adornment-end" }, [TAnswerStatus.streaming, TAnswerStatus.rendering, TAnswerStatus.loading].includes(lastInteractionStatus) ? (h("orama-button", { type: "submit", onClick: this.handleAbortAnswerClick, onKeyDown: this.handleAbortAnswerClick, disabled: lastInteractionStatus !== TAnswerStatus.rendering, "aria-label": "Abort answer" }, h("ph-stop-circle", { size: 16 }))) : (h("orama-button", { type: "submit", onClick: this.handleSubmit, onKeyDown: this.handleSubmit, disabled: !this.inputValue, "aria-label": "Send question" }, h("ph-paper-plane-tilt", { size: 16 }))))))), this.disclaimer && (h("orama-text", { key: '0944eaf9c83b0471eb44fac880cea73efb8a1684', as: "p", styledAs: "small", align: "center", class: "disclaimer-text" }, this.disclaimer)))));
    }
    static get is() { return "orama-chat"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-chat.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-chat.css"]
        };
    }
    static get properties() {
        return {
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Ask me anything'"
            },
            "sourceBaseUrl": {
                "type": "string",
                "attribute": "source-base-url",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "linksTarget": {
                "type": "string",
                "attribute": "links-target",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "linksRel": {
                "type": "string",
                "attribute": "links-rel",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "sourcesMap": {
                "type": "unknown",
                "attribute": "sources-map",
                "mutable": false,
                "complexType": {
                    "original": "SourcesMap",
                    "resolved": "SourcesMapItem[] | { path?: string | NewType; description?: string | NewType; title?: string | NewType; } & { datasourceId?: string; }",
                    "references": {
                        "SourcesMap": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::SourcesMap"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "showClearChat": {
                "type": "boolean",
                "attribute": "show-clear-chat",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "defaultTerm": {
                "type": "string",
                "attribute": "default-term",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "focusInput": {
                "type": "boolean",
                "attribute": "focus-input",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "suggestions": {
                "type": "unknown",
                "attribute": "suggestions",
                "mutable": false,
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "relatedQueries": {
                "type": "number",
                "attribute": "related-queries",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "prompt": {
                "type": "string",
                "attribute": "prompt",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "systemPrompts": {
                "type": "unknown",
                "attribute": "system-prompts",
                "mutable": false,
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "clearChatOnDisconnect": {
                "type": "boolean",
                "attribute": "clear-chat-on-disconnect",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "dictionary": {
                "type": "unknown",
                "attribute": "dictionary",
                "mutable": false,
                "complexType": {
                    "original": "Partial<Dictionary>",
                    "resolved": "{ searchPlaceholder?: string; chatPlaceholder?: string; noResultsFound?: string; noResultsFoundFor?: string; suggestions?: string; seeAll?: string; addMore?: string; clearChat?: string; errorMessage?: string; disclaimer?: string; startYourSearch?: string; initErrorSearch?: string; initErrorChat?: string; chatButtonLabel?: string; searchButtonLabel?: string; }",
                    "references": {
                        "Partial": {
                            "location": "global",
                            "id": "global::Partial"
                        },
                        "Dictionary": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::Dictionary"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "disclaimer": {
                "type": "string",
                "attribute": "disclaimer",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'Orama can make mistakes. Please verify the information.'"
            },
            "chatMarkdownLinkTitle": {
                "type": "unknown",
                "attribute": "chat-markdown-link-title",
                "mutable": false,
                "complexType": {
                    "original": "ChatMarkdownLinkTitle",
                    "resolved": "({ text, href }: { text: string; href: string; }) => string",
                    "references": {
                        "ChatMarkdownLinkTitle": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::ChatMarkdownLinkTitle"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "chatMarkdownLinkHref": {
                "type": "unknown",
                "attribute": "chat-markdown-link-href",
                "mutable": false,
                "complexType": {
                    "original": "ChatMarkdownLinkHref",
                    "resolved": "({ text, href }: { text: string; href: string; }) => string",
                    "references": {
                        "ChatMarkdownLinkHref": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::ChatMarkdownLinkHref"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "chatMarkdownLinkTarget": {
                "type": "unknown",
                "attribute": "chat-markdown-link-target",
                "mutable": false,
                "complexType": {
                    "original": "ChatMarkdownLinkTarget",
                    "resolved": "({ text, href }: { text: string; href: string; }) => string",
                    "references": {
                        "ChatMarkdownLinkTarget": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::ChatMarkdownLinkTarget"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "inputValue": {},
            "showGoToBottomButton": {}
        };
    }
    static get events() {
        return [{
                "method": "answerGenerated",
                "name": "answerGenerated",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "OnAnswerGeneratedCallbackProps",
                    "resolved": "{ askParams: AskParams; query: string; sources: Results<unknown>; answer: string; segment: string; trigger: string; }",
                    "references": {
                        "OnAnswerGeneratedCallbackProps": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::OnAnswerGeneratedCallbackProps"
                        }
                    }
                }
            }, {
                "method": "clearChat",
                "name": "clearChat",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }, {
                "method": "startConversation",
                "name": "startConversation",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "onStartConversationCallbackProps",
                    "resolved": "{ userPrompt: string; systemPrompts: string[]; }",
                    "references": {
                        "onStartConversationCallbackProps": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::onStartConversationCallbackProps"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "defaultTerm",
                "methodName": "handleDefaultTermChange"
            }, {
                "propName": "focusInput",
                "methodName": "focusInputWatcher"
            }, {
                "propName": "prompt",
                "methodName": "promptWatcher"
            }, {
                "propName": "dictionary",
                "methodName": "handleTextDictionaryChange"
            }];
    }
    static get listeners() {
        return [{
                "name": "sourceItemClick",
                "method": "handleSourceItemClick",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
__decorate([
    Store('chat')
], OramaChat.prototype, "chatStore", void 0);
//# sourceMappingURL=orama-chat.js.map
