import { h } from "@stencil/core";
/**
 * The orama-facets component renders a list of facets
 */
export class OramaFacets {
    handleClick(facet) {
        this.selectedFacetChanged(facet.name);
    }
    getFacetButtonElementId(facetName) {
        return `${facetName}-facet-button`;
    }
    setFocusToFacetElement(facetName) {
        const buttonList = this.facetListRef.getElementsByTagName('button');
        for (let i = 0; i < buttonList.length; i++) {
            if (buttonList.item(i).id === this.getFacetButtonElementId(facetName)) {
                buttonList.item(i).focus();
                return;
            }
        }
    }
    handleSelectedFacetChange() {
        var _a;
        this.setFocusToFacetElement(((_a = this.selectedFacet) === null || _a === void 0 ? void 0 : _a.length) ? this.selectedFacet : 'All');
    }
    handleKeyDown(ev) {
        if (['ArrowLeft', 'ArrowRight'].includes(ev.key)) {
            const index = this.selectedFacet ? this.facets.findIndex((facet) => facet.name === this.selectedFacet) : 0;
            if (ev.key === 'ArrowRight') {
                if (index < this.facets.length - 1) {
                    this.selectedFacetChanged(this.facets[index + 1].name);
                }
                else {
                    this.selectedFacetChanged('');
                }
            }
            if (ev.key === 'ArrowLeft') {
                if (index > 1) {
                    this.selectedFacetChanged(this.facets[index - 1].name);
                }
                else if (index - 1 === 0) {
                    this.selectedFacetChanged('');
                }
                else {
                    this.selectedFacetChanged(this.facets[this.facets.length - 1].name);
                }
            }
        }
    }
    render() {
        var _a;
        if (!this.facets || this.facets.every((facet) => !facet.count)) {
            return null;
        }
        return (h("ul", { class: "facets-list", ref: (el) => (this.facetListRef = el) }, (_a = this.facets) === null || _a === void 0 ? void 0 : _a.map((facet) => {
            if ((facet === null || facet === void 0 ? void 0 : facet.count) === 0) {
                return;
            }
            const isSelected = this.selectedFacet === (facet === null || facet === void 0 ? void 0 : facet.name) || (!this.selectedFacet && (facet === null || facet === void 0 ? void 0 : facet.name) === 'All');
            return (h("li", { key: facet.name, class: "facet" }, h("button", { id: this.getFacetButtonElementId(facet.name), type: "button", class: {
                    'facet-button': true,
                    'facet-button--selected': isSelected,
                }, tabIndex: isSelected ? 0 : -1, onClick: () => this.handleClick(facet) }, facet === null || facet === void 0 ? void 0 :
                facet.name, h("span", { class: "facet-count" }, facet === null || facet === void 0 ? void 0 : facet.count))));
        })));
    }
    static get is() { return "orama-facets"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-facets.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-facets.css"]
        };
    }
    static get properties() {
        return {
            "facets": {
                "type": "unknown",
                "attribute": "facets",
                "mutable": false,
                "complexType": {
                    "original": "Facet[]",
                    "resolved": "Facet[]",
                    "references": {
                        "Facet": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::Facet"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "selectedFacet": {
                "type": "string",
                "attribute": "selected-facet",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "selectedFacetChanged": {
                "type": "unknown",
                "attribute": "selected-facet-changed",
                "mutable": false,
                "complexType": {
                    "original": "(facetName: string) => void",
                    "resolved": "(facetName: string) => void",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get watchers() {
        return [{
                "propName": "selectedFacet",
                "methodName": "handleSelectedFacetChange"
            }];
    }
    static get listeners() {
        return [{
                "name": "keydown",
                "method": "handleKeyDown",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
//# sourceMappingURL=orama-facets.js.map
