import { h, Host } from "@stencil/core";
import "@phosphor-icons/webcomponents/dist/icons/PhArrowBendDownLeft.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhArrowUp.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhArrowDown.mjs";
/**
 * The orama-footer component is used to render a footer element with logo and keyboard shortcuts.
 */
export class OramaFooter {
    constructor() {
        this.colorScheme = 'light';
        /** Whether to show keyboard shortcuts in the footer */
        this.showKeyboardShortcuts = false;
        this.linkTarget = '_blank';
        /** Keyboard shortcuts to display */
        this.keyboardShortcuts = [
            { name: 'select', key: 'Enter', icon: 'arrow-bend-down-left', description: 'to select' },
            { name: 'navigate', key: '↑ ↓', icon: 'arrows-vertical', description: 'to navigate' },
            { name: 'close', key: 'Esc', icon: 'esc', description: 'to close' },
        ];
    }
    componentWillLoad() {
        const utmSource = encodeURIComponent(window.location.hostname);
        this.poweredByDestinationUrl = `https://www.orama.com/?utm_source=${utmSource}&utm_medium=powered-by`;
        if (['localhost', 'orama.com'].includes(utmSource)) {
            this.linkTarget = '_parent';
        }
    }
    renderIcon(shortcut) {
        // Special case for ESC key
        if (shortcut.icon === 'esc') {
            return (h("div", null, h("span", { class: "shortcut-icon" }, h("span", { class: "esc-text" }, "esc"))));
        }
        // For Phosphor icons
        switch (shortcut.icon) {
            case 'arrow-bend-down-left':
                return (h("span", { class: "shortcut-icon" }, h("ph-arrow-bend-down-left", { size: 16 })));
            case 'arrows-vertical':
                return (h("div", { class: "arrows-container" }, h("span", { class: "shortcut-icon" }, h("ph-arrow-up", { size: 16 })), h("span", { class: "shortcut-icon" }, h("ph-arrow-down", { size: 16 }))));
            default:
                return null;
        }
    }
    render() {
        const imgName = this.colorScheme === 'dark' ? 'orama-when-dark.svg' : 'orama-when-light.svg';
        return (h(Host, { key: 'b21ad31b55a56c189efdf83b7f745dfc149af388' }, this.showKeyboardShortcuts && (h("div", { key: '0af21a82002e38855e83176b7e6dc0f2e8aebe8b', class: "keyboard-shortcuts", "aria-label": "Keyboard shortcuts" }, this.keyboardShortcuts.map((shortcut) => (h("div", { class: "shortcut-item" }, this.renderIcon(shortcut), h("orama-text", { as: "small", variant: "tertiary" }, h("span", { class: "shortcut-description" }, shortcut.description))))))), h("div", { key: '67dec2fc22297ff7a7f47eb4e112b14a3801c378', class: "powered-by" }, h("a", { key: 'ef8d9ea69bb7207ea1279ede9576e4cb03d4cf12', href: this.poweredByDestinationUrl, target: this.linkTarget, rel: "noopener noreferrer", class: "logo-link" }, h("orama-text", { key: '49bcbd36198dfd2200d6902f65ea88f573974c4e', as: "small" }, "Powered by"), h("img", { key: 'f8d46510486a83866fa3b24f5d38f60fe8ce3d6b', src: `https://website-assets.oramasearch.com/${imgName}`, alt: "Powered by Orama", class: "logo", width: 62 })))));
    }
    static get is() { return "orama-footer"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-footer.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-footer.css"]
        };
    }
    static get properties() {
        return {
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "colorScheme": {
                "type": "unknown",
                "attribute": "color-scheme",
                "mutable": false,
                "complexType": {
                    "original": "Omit<ColorScheme, 'system'>",
                    "resolved": "{ readonly [x: number]: string; [Symbol.iterator]: () => IterableIterator<string>; charAt: (pos: number) => string; charCodeAt: (index: number) => number; concat: (...strings: string[]) => string; indexOf: (searchString: string, position?: number) => number; lastIndexOf: (searchString: string, position?: number) => number; localeCompare: { (that: string): number; (that: string, locales?: string | string[], options?: CollatorOptions): number; (that: string, locales?: LocalesArgument, options?: CollatorOptions): number; }; match: { (regexp: string | RegExp): RegExpMatchArray; (matcher: { [Symbol.match](string: string): RegExpMatchArray; }): RegExpMatchArray; }; replace: { (searchValue: string | RegExp, replaceValue: string): string; (searchValue: string | RegExp, replacer: (substring: string, ...args: any[]) => string): string; (searchValue: { [Symbol.replace](string: string, replaceValue: string): string; }, replaceValue: string): string; (searchValue: { [Symbol.replace](string: string, replacer: (substring: string, ...args: any[]) => string): string; }, replacer: (substring: string, ...args: any[]) => string): string; }; search: { (regexp: string | RegExp): number; (searcher: { [Symbol.search](string: string): number; }): number; }; slice: (start?: number, end?: number) => string; split: { (separator: string | RegExp, limit?: number): string[]; (splitter: { [Symbol.split](string: string, limit?: number): string[]; }, limit?: number): string[]; }; substring: (start: number, end?: number) => string; toLowerCase: () => string; toLocaleLowerCase: { (locales?: string | string[]): string; (locales?: LocalesArgument): string; }; toUpperCase: () => string; toLocaleUpperCase: { (locales?: string | string[]): string; (locales?: LocalesArgument): string; }; trim: () => string; readonly length: number; substr: (from: number, length?: number) => string; codePointAt: (pos: number) => number; includes: (searchString: string, position?: number) => boolean; endsWith: (searchString: string, endPosition?: number) => boolean; normalize: { (form: \"NFC\" | \"NFD\" | \"NFKC\" | \"NFKD\"): string; (form?: string): string; }; repeat: (count: number) => string; startsWith: (searchString: string, position?: number) => boolean; anchor: (name: string) => string; big: () => string; blink: () => string; bold: () => string; fixed: () => string; fontcolor: (color: string) => string; fontsize: { (size: number): string; (size: string): string; }; italics: () => string; link: (url: string) => string; small: () => string; strike: () => string; sub: () => string; sup: () => string; padStart: (maxLength: number, fillString?: string) => string; padEnd: (maxLength: number, fillString?: string) => string; trimEnd: () => string; trimStart: () => string; trimLeft: () => string; trimRight: () => string; matchAll: (regexp: RegExp) => IterableIterator<RegExpExecArray>; at: (index: number) => string; toString: () => string; valueOf: () => string; }",
                    "references": {
                        "Omit": {
                            "location": "global",
                            "id": "global::Omit"
                        },
                        "ColorScheme": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::ColorScheme"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "'light'"
            },
            "showKeyboardShortcuts": {
                "type": "boolean",
                "attribute": "show-keyboard-shortcuts",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Whether to show keyboard shortcuts in the footer"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=orama-footer.js.map
