import { Host, h } from "@stencil/core";
import "@phosphor-icons/webcomponents/dist/icons/PhX.mjs";
import "@phosphor-icons/webcomponents/dist/icons/PhMagnifyingGlass.mjs";
import { getNonExplicitAttributes } from "../../../utils/utils";
export class Input {
    constructor() {
        this.size = 'medium';
        this.type = 'text';
        this.autoFocus = false;
    }
    handleAutoFocusChange() {
        var _a;
        if (this.autoFocus) {
            (_a = this.inputRef) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }
    ensureFocus() {
        const checkRefInterval = setInterval(() => {
            if (this.inputRef) {
                this.inputRef.focus();
                clearInterval(checkRefInterval);
            }
        }, 10);
    }
    componentDidLoad() {
        if (this.autoFocus) {
            this.ensureFocus();
        }
    }
    render() {
        const inputClass = `input input--${this.size}`;
        const labelClass = `label ${this.labelForScreenReaders ? 'sr-only' : ''}`;
        const declaredProps = [
            'id',
            'name',
            'type',
            'class',
            'onInput',
            'value',
            'label-for-screen-readers',
            'default-value',
            'placeholder',
        ];
        const inputProps = getNonExplicitAttributes(this.el, declaredProps);
        const isSearch = this.type === 'search';
        return (h(Host, { key: '2618def598b4bcffcb974d761937c304f36d70cf' }, h("div", { key: '07b0b637d645dfcd43dab6f20256b548f42672bb', class: "wrapper" }, h("label", { key: 'c8e3e0ee0962064c613ccbfa459873e8e80ee32a', htmlFor: this.name, class: labelClass }, this.label || this.labelForScreenReaders), h("div", { key: '7c78f6d5e491b17094d86ef89c4461178e1e620c', class: "input-wrapper" }, isSearch && (h("span", { key: '07a43ba5606596d2b2834bb3dc040573d7039a05', class: "search-icon" }, h("ph-magnifying-glass", { key: '3097468ab3864e7a29121e5f5978cf6f4a14f006', size: 16 }))), h("input", Object.assign({ key: '5ee32af4e927d3f717345a2d2337793ba28d9c43' }, inputProps, { ref: (el) => {
                this.inputRef = el;
            }, class: inputClass, id: this.name, type: this.type, value: this.value, onInput: (event) => {
                const target = event.target;
                this.inputChanged.emit(target.value);
            }, placeholder: this.placeholder })), isSearch && !!this.value && (h("button", { key: '13c7ee67fdafb756fda92b7d7739fccc367b8f20', type: "button", class: "reset-button", onClick: () => {
                this.inputRef.focus();
                this.inputChanged.emit('');
            } }, h("ph-x", { key: 'b24dec02e1a86d9205ee4a4025472571ac941fbe', size: 16 })))))));
    }
    static get is() { return "orama-input"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-input.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-input.css"]
        };
    }
    static get properties() {
        return {
            "name": {
                "type": "string",
                "attribute": "name",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['name']",
                    "resolved": "string",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "size": {
                "type": "string",
                "attribute": "size",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['size']",
                    "resolved": "\"large\" | \"medium\" | \"small\"",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'medium'"
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['label']",
                    "resolved": "string",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['type']",
                    "resolved": "\"email\" | \"number\" | \"password\" | \"search\" | \"tel\" | \"text\" | \"url\"",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'text'"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['placeholder']",
                    "resolved": "string",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "labelForScreenReaders": {
                "type": "string",
                "attribute": "label-for-screen-readers",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['labelForScreenReaders']",
                    "resolved": "string",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "defaultValue": {
                "type": "string",
                "attribute": "default-value",
                "mutable": false,
                "complexType": {
                    "original": "InputProps['defaultValue']",
                    "resolved": "string",
                    "references": {
                        "InputProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-input/orama-input.tsx",
                            "id": "src/components/internal/orama-input/orama-input.tsx::InputProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "autoFocus": {
                "type": "boolean",
                "attribute": "auto-focus",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get events() {
        return [{
                "method": "inputChanged",
                "name": "inputChanged",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "autoFocus",
                "methodName": "handleAutoFocusChange"
            }];
    }
}
//# sourceMappingURL=orama-input.js.map
