import { h } from "@stencil/core";
export class OramaModal {
    constructor() {
        this.closeOnEscape = true;
        this.closeOnOutsideClick = true;
        this.mainTitle = '';
        this.originalBodyOverflowState = 'scroll';
    }
    trapFocus(event) {
        const focusableElements = this.el.querySelectorAll('a[href], button, textarea, input, select, [tabindex]:not([tabindex="-1"])');
        const focusableArray = Array.from(focusableElements).filter((element) => element.offsetParent !== null);
        if (focusableArray.length > 0) {
            this.firstFocusableElement = focusableArray[0];
            this.lastFocusableElement = focusableArray[focusableArray.length - 1];
            const focusedElement = this.el.querySelector(':focus');
            if (event.shiftKey && focusedElement === this.firstFocusableElement) {
                event.preventDefault();
                this.lastFocusableElement.focus();
            }
            else if (!event.shiftKey && focusedElement === this.lastFocusableElement) {
                event.preventDefault();
                this.firstFocusableElement.focus();
            }
        }
    }
    handleFocus() {
        const focusableElements = this.el.querySelectorAll('a[href], button, textarea, input, select, [tabindex]:not([tabindex="-1"])');
        const focusableArray = Array.from(focusableElements).filter((element) => element.offsetParent !== null);
        if (focusableArray.length > 0) {
            focusableArray[0].focus();
        }
    }
    connectedCallback() {
        this.originalBodyOverflowState = document.body.style.overflow;
        this.activeElement = document.activeElement;
        this.handleFocus();
        document.body.style.overflow = 'hidden';
    }
    disconnectedCallback() {
        document.body.style.overflow = this.originalBodyOverflowState;
    }
    componentDidUpdate() {
        this.handleFocus();
        if (this.activeElement) {
            this.activeElement.focus();
        }
    }
    render() {
        return (h("dialog", { key: 'a3fc3367ed30a5b2c440df67600bf619652b559c', class: 'modal open', "aria-modal": "true", "aria-labelledby": "modalTitle", "aria-describedby": "modalContent", onKeyDown: (event) => {
                switch (event.key) {
                    case 'Tab':
                        this.trapFocus(event);
                        break;
                    case 'Escape':
                        if (this.closeOnEscape) {
                            event.preventDefault();
                            event.stopPropagation();
                            this.modalClosed.emit();
                        }
                        break;
                }
            }, onClick: (event) => {
                if (this.innerModalRef && !this.innerModalRef.contains(event.target)) {
                    event.stopPropagation();
                    event.preventDefault();
                    this.modalClosed.emit();
                }
            } }, h("div", { key: '4eff2c8624762dc014b85851590abed2cf8f38c3', class: "modal-inner", ref: (ref) => (this.innerModalRef = ref) }, h("h1", { key: 'd4360fef432f56884b54c5bdfac5d8bfa6e530ef', id: "modalTitle", class: "modal-title" }, this.mainTitle), h("div", { key: '9e3867727679699c7d31e71b7d637c6d4cb24334', id: "modalContent", class: "modal-content" }, h("slot", { key: 'deb12898e6327dc99b52ae8d48444c0d09b2320d' })), h("button", { key: '43dfa57f3117c030474c707113208aa954cf68f4', onClick: () => this.modalClosed.emit(), type: "button", class: "modal-close" }, "Close"))));
    }
    static get is() { return "orama-modal"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-modal.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-modal.css"]
        };
    }
    static get properties() {
        return {
            "closeOnEscape": {
                "type": "boolean",
                "attribute": "close-on-escape",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "closeOnOutsideClick": {
                "type": "boolean",
                "attribute": "close-on-outside-click",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "true"
            },
            "mainTitle": {
                "type": "string",
                "attribute": "main-title",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            }
        };
    }
    static get states() {
        return {
            "activeElement": {}
        };
    }
    static get events() {
        return [{
                "method": "modalClosed",
                "name": "modalClosed",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=orama-modal.js.map
