import { Host, h } from "@stencil/core";
import { Highlight } from "@orama/highlight";
import "@phosphor-icons/webcomponents/dist/icons/PhFiles.mjs";
import { Icon } from "../icons";
export class SearchResults {
    constructor() {
        this.linksTarget = '_blank';
        this.linksRel = 'noopener noreferrer';
        this.sections = [];
        this.suggestions = [];
        this.loading = false;
        this.error = false;
        this.highlightTitle = false;
        this.highlightDescription = false;
        this.handleItemClick = (originalOnClickEvent, item) => {
            const searchResultClick = this.searchResultClick.emit({ result: item });
            if (searchResultClick.defaultPrevented) {
                originalOnClickEvent.preventDefault();
                return;
            }
            if (!(item === null || item === void 0 ? void 0 : item.path)) {
                throw new Error('No path found');
            }
        };
        this.getItemLinkUrl = (item) => {
            if (item === null || item === void 0 ? void 0 : item.path) {
                return this.sourceBaseUrl ? `${this.sourceBaseUrl}${item.path}` : item.path;
            }
            return '#';
        };
        this.getHighlightedTitleText = (text) => {
            return this.highlighterTitle.highlight(text, this.searchTerm);
        };
        this.getHighlightedDescriptionText = (text) => {
            return this.highlighterDescription.highlight(text, this.searchTerm);
        };
    }
    buildUrl(path) {
        if (!path) {
            return '#';
        }
        if (this.sourceBaseUrl) {
            // Remove trailing slashes from the base URL
            const sanitizedBaseUrl = this.sourceBaseUrl.replace(/\/+$/, '');
            // Remove leading slashes from the path
            const sanitizedPath = path.replace(/^\/+/, '');
            // Concatenate the base URL with the path
            return `${sanitizedBaseUrl}/${sanitizedPath}`;
        }
        return path;
    }
    componentDidLoad() {
        if (this.highlightTitle) {
            this.highlighterTitle = new Highlight(this.highlightTitle);
        }
        if (this.highlightDescription) {
            this.highlighterDescription = new Highlight(this.highlightDescription);
        }
    }
    render() {
        var _a, _b, _c, _d, _e, _f;
        if (!this.searchTerm) {
            return (h("div", { class: "suggestions-wrapper" }, !!((_a = this.suggestions) === null || _a === void 0 ? void 0 : _a.length) && (h("orama-text", { as: "h2", styledAs: "small", class: "suggestions-title", variant: "secondary" }, ((_b = this.dictionary) === null || _b === void 0 ? void 0 : _b.suggestions) || 'Suggestions')), h("orama-suggestions", { as: "list", suggestions: this.suggestions, icon: h(Icon, { name: "starFour", size: 16, color: "var(--text-color-accent, text-color('accent')" }), suggestionClicked: (term) => {
                    this.setChatTerm(term);
                } })));
        }
        if (this.error) {
            return h("div", null, ((_c = this.dictionary) === null || _c === void 0 ? void 0 : _c.errorMessage) || 'An error occurred while trying to search. Please try again.');
        }
        if (!this.loading && !((_d = this.sections) === null || _d === void 0 ? void 0 : _d.some((section) => section.items.length > 0))) {
            return (h("div", { class: "results-empty" }, h("orama-text", { as: "h3", styledAs: "span" }, `${((_e = this.dictionary) === null || _e === void 0 ? void 0 : _e.noResultsFound) || 'No results found'} ${this.searchTerm ? `${((_f = this.dictionary) === null || _f === void 0 ? void 0 : _f.noResultsFoundFor) || 'for'} "${this.searchTerm}"` : ''}`)));
        }
        return (h(Host, null, h("ul", { class: "list section-list" }, this.sections.map((section) => (h("div", { key: section.section, class: "section-wrapper" }, section.section && (h("div", { class: "section-title-wrapper" }, h("orama-text", { as: "h2", styledAs: "span" }, section.section))), h("ul", { class: "list section-item-list" }, section.items.map((result) => (h("li", { class: "list-item", key: result.id }, h("a", { "focus-on-arrow-nav": true, href: this.buildUrl(result.path), class: "list-item-button", target: this.linksTarget, rel: this.linksRel, id: `search-result-${result.id}`, onClick: (onClickEvent) => this.handleItemClick(onClickEvent, result) }, h("div", { class: "result-item-icon-wrapper" }, result.icon ? (h("img", { alt: "", class: "custom-result-item-icon", src: result.icon })) : (h("ph-files", { size: "20px" }))), h("div", { class: "textWrapper" }, h("orama-text", { as: "h3", styledAs: "p", class: "result-title collapsed" }, !this.highlightTitle ? (h("span", { innerHTML: result.title })) : result.title.length > 200 ? ( // Trim exists here to prevent to render too much data to the DOM
        h("span", { innerHTML: this.getHighlightedTitleText(result.title).trim(200) })) : (h("span", { innerHTML: this.getHighlightedTitleText(result.title).HTML }))), h("orama-text", { as: "p", styledAs: "span", class: "result-description collapsed", variant: "tertiary" }, !this.highlightDescription ? (h("span", { innerHTML: result.description })) : (h("span", { innerHTML: this.getHighlightedDescriptionText(result.description).HTML })))))))))))))));
    }
    static get is() { return "orama-search-results"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-search-results.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-search-results.css"]
        };
    }
    static get properties() {
        return {
            "sourceBaseUrl": {
                "type": "string",
                "attribute": "source-base-url",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "linksTarget": {
                "type": "string",
                "attribute": "links-target",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'_blank'"
            },
            "linksRel": {
                "type": "string",
                "attribute": "links-rel",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'noopener noreferrer'"
            },
            "sections": {
                "type": "unknown",
                "attribute": "sections",
                "mutable": false,
                "complexType": {
                    "original": "SearchResultBySection[]",
                    "resolved": "SearchResultBySection[]",
                    "references": {
                        "SearchResultBySection": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::SearchResultBySection"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "suggestions": {
                "type": "unknown",
                "attribute": "suggestions",
                "mutable": false,
                "complexType": {
                    "original": "string[]",
                    "resolved": "string[]",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "searchTerm": {
                "type": "string",
                "attribute": "search-term",
                "mutable": false,
                "complexType": {
                    "original": "SearchResultsProps['searchTerm']",
                    "resolved": "string",
                    "references": {
                        "SearchResultsProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-search-results/orama-search-results.tsx",
                            "id": "src/components/internal/orama-search-results/orama-search-results.tsx::SearchResultsProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "setChatTerm": {
                "type": "unknown",
                "attribute": "set-chat-term",
                "mutable": false,
                "complexType": {
                    "original": "(term: string) => void",
                    "resolved": "(term: string) => void",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "loading": {
                "type": "boolean",
                "attribute": "loading",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "error": {
                "type": "boolean",
                "attribute": "error",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "highlightTitle": {
                "type": "boolean",
                "attribute": "highlight-title",
                "mutable": false,
                "complexType": {
                    "original": "HighlightOptions | false",
                    "resolved": "HighlightOptions | boolean",
                    "references": {
                        "HighlightOptions": {
                            "location": "import",
                            "path": "@orama/highlight",
                            "id": "../../node_modules/.pnpm/@orama+highlight@0.1.9/node_modules/@orama/highlight/dist/index.d.ts::HighlightOptions"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "highlightDescription": {
                "type": "boolean",
                "attribute": "highlight-description",
                "mutable": false,
                "complexType": {
                    "original": "HighlightOptions | false",
                    "resolved": "HighlightOptions | boolean",
                    "references": {
                        "HighlightOptions": {
                            "location": "import",
                            "path": "@orama/highlight",
                            "id": "../../node_modules/.pnpm/@orama+highlight@0.1.9/node_modules/@orama/highlight/dist/index.d.ts::HighlightOptions"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "dictionary": {
                "type": "unknown",
                "attribute": "dictionary",
                "mutable": false,
                "complexType": {
                    "original": "Partial<Dictionary>",
                    "resolved": "{ searchPlaceholder?: string; chatPlaceholder?: string; noResultsFound?: string; noResultsFoundFor?: string; suggestions?: string; seeAll?: string; addMore?: string; clearChat?: string; errorMessage?: string; disclaimer?: string; startYourSearch?: string; initErrorSearch?: string; initErrorChat?: string; chatButtonLabel?: string; searchButtonLabel?: string; }",
                    "references": {
                        "Partial": {
                            "location": "global",
                            "id": "global::Partial"
                        },
                        "Dictionary": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::Dictionary"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get events() {
        return [{
                "method": "searchResultClick",
                "name": "searchResultClick",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "OnSearchResultClickCallbackProps",
                    "resolved": "{ result: SearchResult; }",
                    "references": {
                        "OnSearchResultClickCallbackProps": {
                            "location": "import",
                            "path": "@/types",
                            "id": "src/types/index.ts::OnSearchResultClickCallbackProps"
                        }
                    }
                }
            }];
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=orama-search-results.js.map
