import { h } from "@stencil/core";
import { getNonExplicitAttributes } from "../../../utils/utils";
/**
 * The OramaText component is used to render a text element with a specific style.
 *
 */
export class OramaText {
    constructor() {
        this.as = 'p';
        this.bold = false;
        this.variant = 'primary';
    }
    render() {
        const defaultStyle = this.styledAs === 'span' || this.styledAs === 'small' || this.styledAs === 'p' ? this.styledAs : this.as;
        const Tag = this.as;
        const declaredProps = ['as', 'styled-as', 'class'];
        const textProps = getNonExplicitAttributes(this.el, declaredProps);
        return (h(Tag, Object.assign({ key: 'a1c41477fc4643a8fd1eba038a39117311e17a20', class: {
                [defaultStyle]: true,
                [`text-${this.align}`]: !!this.align,
                [`${defaultStyle}-${this.variant}`]: true,
                'text-inactive': !!this.inactive,
                'text-bold': !!this.bold,
                [this.class]: !!this.class,
            } }, textProps), h("slot", { key: 'd78c56927befa49cf5f54ab77dd76c9ab3797770' })));
    }
    static get is() { return "orama-text"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-text.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-text.css"]
        };
    }
    static get properties() {
        return {
            "as": {
                "type": "string",
                "attribute": "as",
                "mutable": false,
                "complexType": {
                    "original": "TextProps['as']",
                    "resolved": "\"a\" | \"h1\" | \"h2\" | \"h3\" | \"h4\" | \"h5\" | \"h6\" | \"p\" | \"small\" | \"span\"",
                    "references": {
                        "TextProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-text/orama-text.tsx",
                            "id": "src/components/internal/orama-text/orama-text.tsx::TextProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "it defines the HTML tag to be used"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'p'"
            },
            "styledAs": {
                "type": "string",
                "attribute": "styled-as",
                "mutable": false,
                "complexType": {
                    "original": "TextProps['styledAs']",
                    "resolved": "\"p\" | \"small\" | \"span\"",
                    "references": {
                        "TextProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-text/orama-text.tsx",
                            "id": "src/components/internal/orama-text/orama-text.tsx::TextProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "it defines how it should look like"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "bold": {
                "type": "boolean",
                "attribute": "bold",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "class": {
                "type": "string",
                "attribute": "class",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "the optional class name"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "align": {
                "type": "string",
                "attribute": "align",
                "mutable": false,
                "complexType": {
                    "original": "TextProps['align']",
                    "resolved": "\"center\" | \"left\" | \"right\"",
                    "references": {
                        "TextProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-text/orama-text.tsx",
                            "id": "src/components/internal/orama-text/orama-text.tsx::TextProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "optionally change text alignment"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "variant": {
                "type": "string",
                "attribute": "variant",
                "mutable": false,
                "complexType": {
                    "original": "TextProps['variant']",
                    "resolved": "\"primary\" | \"secondary\" | \"tertiary\"",
                    "references": {
                        "TextProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-text/orama-text.tsx",
                            "id": "src/components/internal/orama-text/orama-text.tsx::TextProps"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "optionally change variant style - default is primary"
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'primary'"
            },
            "inactive": {
                "type": "boolean",
                "attribute": "inactive",
                "mutable": false,
                "complexType": {
                    "original": "TextProps['inactive']",
                    "resolved": "boolean",
                    "references": {
                        "TextProps": {
                            "location": "local",
                            "path": "/home/runner/work/orama-ui-components/orama-ui-components/packages/ui-stencil/src/components/internal/orama-text/orama-text.tsx",
                            "id": "src/components/internal/orama-text/orama-text.tsx::TextProps"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "show as inactive"
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get elementRef() { return "el"; }
}
//# sourceMappingURL=orama-text.js.map
