import { Host, h } from "@stencil/core";
export class OramaTextarea {
    constructor() {
        this.value = '';
        this.minRows = 1;
        this.autoFocus = false;
        this.handleChange = (event) => {
            const target = event.target;
            if (!this.value) {
                this.syncHeight();
            }
            this.value = target.value;
        };
    }
    handleAutoFocusChange() {
        if (this.autoFocus) {
            this.textarea.focus();
        }
    }
    componetWillLoad() {
        this.startAdornmentWidth = this.getNamedSlotWidth('adornment-start');
        this.endAdornmentWidth = this.getNamedSlotWidth('adornment-end');
        this.syncHeight();
        if (this.autoFocus) {
            this.textarea.focus();
        }
    }
    getNamedSlotWidth(slotName) {
        const slot = this.el.querySelector(`slot[name="${slotName}"]`);
        if (slot) {
            const assignedElements = slot.assignedElements();
            if (assignedElements.length > 0) {
                const firstAssignedElement = assignedElements[0];
                const width = firstAssignedElement.offsetWidth;
                return width;
            }
        }
        return 0;
    }
    handlePropsChange() {
        this.syncHeight();
    }
    getStyleValue(value) {
        return Number.parseInt(value, 10) || 0;
    }
    calculateTextareaStyles() {
        const input = this.textarea;
        const computedStyle = window.getComputedStyle(input);
        if (computedStyle.width === '0px') {
            return {
                outerHeightStyle: 0,
                overflowing: false,
            };
        }
        const inputShallow = this.shadowTextarea;
        inputShallow.style.width = computedStyle.width;
        inputShallow.value = input.value || this.placeholder || 'x';
        if (inputShallow.value.slice(-1) === '\n') {
            inputShallow.value += ' ';
        }
        const boxSizing = computedStyle.boxSizing;
        const padding = this.getStyleValue(computedStyle.paddingBottom) + this.getStyleValue(computedStyle.paddingTop);
        const border = this.getStyleValue(computedStyle.borderBottomWidth) + this.getStyleValue(computedStyle.borderTopWidth);
        const innerHeight = inputShallow.scrollHeight;
        inputShallow.value = 'x';
        const singleRowHeight = inputShallow.scrollHeight;
        let outerHeight = innerHeight;
        if (this.minRows) {
            outerHeight = Math.max(Number(this.minRows) * singleRowHeight, outerHeight);
        }
        if (this.maxRows) {
            outerHeight = Math.min(Number(this.maxRows) * singleRowHeight, outerHeight);
        }
        outerHeight = Math.max(outerHeight, singleRowHeight);
        const outerHeightStyle = outerHeight + (boxSizing === 'border-box' ? padding + border : 0);
        const overflowing = Math.abs(outerHeight - innerHeight) <= 1;
        return { outerHeightStyle, overflowing };
    }
    syncHeight() {
        const textareaStyles = this.calculateTextareaStyles();
        if (!textareaStyles) {
            return;
        }
        const outerHeightStyle = textareaStyles.outerHeightStyle;
        if (this.height !== outerHeightStyle) {
            this.height = outerHeightStyle;
            this.textarea.style.height = `${outerHeightStyle}px`;
        }
        this.textarea.style.overflow = textareaStyles.overflowing ? 'hidden' : '';
    }
    getAllProps() {
        const props = {};
        for (let i = 0; i < this.el.attributes.length; i++) {
            const attr = this.el.attributes[i];
            props[attr.name] = attr.value;
        }
        return props;
    }
    render() {
        return (h(Host, { key: '5d11fb96304062ca9861694d682d8e12064bdb1e' }, h("slot", { key: '17fc62c00745e57cdc27e826f5481f4c6f497e3e', name: "adornment-start" }), h("textarea", Object.assign({ key: '016d07bebfb05aa4f547bffbc2afa3dfc88970bc' }, this.getAllProps(), { value: this.value, onInput: this.handleChange, ref: (el) => (this.textarea = el), rows: Number(this.minRows), style: {
                height: this.height ? `${this.height}px` : undefined,
                paddingLeft: this.startAdornmentWidth ? `${this.startAdornmentWidth}px` : undefined,
                paddingRight: this.endAdornmentWidth ? `${this.endAdornmentWidth}px` : undefined,
            }, class: "textarea", placeholder: this.placeholder })), h("slot", { key: '515eb08d900f216a6e1a70a45287750fb4eec53f', name: "adornment-end" }), h("textarea", { key: '76d4ec4a7a7ecae613a1dc47beec8716e652acab', "aria-hidden": "true", readonly: true, ref: (el) => (this.shadowTextarea = el), tabindex: -1, class: "textarea", style: {
                visibility: 'hidden',
                position: 'absolute',
                overflow: 'hidden',
                height: '0',
                top: '0',
                left: '0',
                transform: 'translateZ(0)',
                paddingTop: '0',
                paddingBottom: '0',
                paddingLeft: this.startAdornmentWidth ? `${this.startAdornmentWidth}px` : undefined,
                paddingRight: this.endAdornmentWidth ? `${this.endAdornmentWidth}px` : undefined,
            } })));
    }
    static get is() { return "orama-textarea"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() {
        return {
            "$": ["orama-textarea.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["orama-textarea.css"]
        };
    }
    static get properties() {
        return {
            "value": {
                "type": "string",
                "attribute": "value",
                "mutable": false,
                "complexType": {
                    "original": "string | null",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "''"
            },
            "maxRows": {
                "type": "any",
                "attribute": "max-rows",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "minRows": {
                "type": "any",
                "attribute": "min-rows",
                "mutable": false,
                "complexType": {
                    "original": "number | string",
                    "resolved": "number | string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "1"
            },
            "placeholder": {
                "type": "string",
                "attribute": "placeholder",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "autoFocus": {
                "type": "boolean",
                "attribute": "auto-focus",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "height": {},
            "startAdornmentWidth": {},
            "endAdornmentWidth": {}
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "autoFocus",
                "methodName": "handleAutoFocusChange"
            }, {
                "propName": "value",
                "methodName": "handlePropsChange"
            }, {
                "propName": "maxRows",
                "methodName": "handlePropsChange"
            }, {
                "propName": "minRows",
                "methodName": "handlePropsChange"
            }];
    }
}
//# sourceMappingURL=orama-textarea.js.map
