var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
};
import { OramaClientNotInitializedError } from "../erros/OramaClientNotInitializ";
import { TAnswerStatus, } from "../types/index";
import { Switch } from "@orama/switch";
const parseRelatedQueries = (relatedQueries) => {
    try {
        return JSON.parse(relatedQueries);
    }
    catch (error) {
        return [];
    }
};
export class ChatService {
    constructor(oramaClient, oramaCoreClient, chatStore) {
        this.getSourcesMapObjectByIndexId = (resultMapArrayOrObject, indexId) => {
            const searchMapArray = Array.isArray(resultMapArrayOrObject) ? resultMapArrayOrObject : [resultMapArrayOrObject];
            // If there is only one source map, assume it's the one for all hits, regardless of datasourceId
            if (searchMapArray.length === 1) {
                return searchMapArray[0];
            }
            // TODO: Instead of doing it per each HIT, we may want to create a map of datasourceId -> resultMap to avoid the O(n) lookup
            const sourcesMapMatch = searchMapArray.find((resultMap) => resultMap.datasourceId === indexId);
            return sourcesMapMatch || {};
        };
        this.sendQuestion = async (term, relatedQueries, systemPrompts, callbacks) => {
            if (!this.client)
                throw new OramaClientNotInitializedError();
            const askParams = {
                term,
            };
            if (systemPrompts === null || systemPrompts === void 0 ? void 0 : systemPrompts.length) {
                if (this.answerSession && 'setSystemPromptConfiguration' in this.answerSession) {
                    ;
                    this.answerSession.setSystemPromptConfiguration(systemPrompts);
                }
            }
            const existingInteractions = this.chatStore.state.interactions;
            if (!this.answerSession) {
                try {
                    const existingInteractions = this.chatStore.state.interactions;
                    try {
                        /* TODO: Inferfaces between Orama Core and Orama Cloud are different.
                          we must cast the client to the correct type and use different implementations.
              
                          We are not doing that for the sake of speed, but we must circle back to this.
                        */
                        this.answerSession = this.client.createAnswerSession({
                            events: {
                                onStateChange: (state) => {
                                    // Filter out empty interactions
                                    const normalizedState = state.filter((stateItem) => !!stateItem.query);
                                    this.chatStore.state.interactions = [
                                        ...(existingInteractions || []),
                                        ...normalizedState.map((interaction, index) => {
                                            var _a;
                                            const isLatest = state.length - 1 === index;
                                            let answerStatus = TAnswerStatus.loading;
                                            let sources = [];
                                            if (interaction.aborted) {
                                                answerStatus = TAnswerStatus.aborted;
                                            }
                                            else if (interaction.loading && interaction.sources) {
                                                answerStatus = TAnswerStatus.rendering;
                                            }
                                            else if (interaction.loading && interaction.response) {
                                                answerStatus = TAnswerStatus.streaming;
                                            }
                                            else if (!interaction.loading && interaction.response) {
                                                answerStatus = TAnswerStatus.done;
                                            }
                                            // Handle sources in different formats
                                            if (interaction.sources) {
                                                const rawSources = Array.isArray(interaction.sources)
                                                    ? interaction.sources
                                                    : interaction.sources.hits;
                                                sources = rawSources.map((source) => {
                                                    const matchingMap = this.getSourcesMapObjectByIndexId(this.chatStore.state.sourcesMap, source.index_id);
                                                    const title = this.getResultMapValue('title', matchingMap, source);
                                                    const description = this.getResultMapValue('description', matchingMap, source);
                                                    const path = this.getResultMapValue('path', matchingMap, source);
                                                    return {
                                                        title,
                                                        description,
                                                        path,
                                                    };
                                                });
                                            }
                                            if (isLatest && answerStatus === TAnswerStatus.done) {
                                                (_a = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onAnswerGeneratedCallback) === null || _a === void 0 ? void 0 : _a.call(callbacks, {
                                                    askParams,
                                                    query: interaction.query,
                                                    sources: interaction.sources,
                                                    answer: interaction.response,
                                                    segment: interaction.segment,
                                                    trigger: interaction.trigger,
                                                });
                                            }
                                            const relatedQueries = interaction.related;
                                            return {
                                                query: interaction.query,
                                                // interactionId for Old Orama and id for Orama Core
                                                interactionId: interaction.interactionId || interaction.id,
                                                response: interaction.response,
                                                relatedQueries: parseRelatedQueries(relatedQueries),
                                                status: answerStatus,
                                                latest: isLatest,
                                                sources,
                                            };
                                        }),
                                    ];
                                },
                            },
                        });
                    }
                    catch (methodError) {
                        console.error('Client does not support createAnswerSession method:', methodError);
                        this.chatStore.state.interactions = [
                            ...(existingInteractions || []),
                            {
                                query: term,
                                response: 'Sorry, this client does not support chat functionality.',
                                status: TAnswerStatus.error,
                                latest: true,
                                sources: [],
                            },
                        ];
                        return;
                    }
                }
                catch (error) {
                    console.error('Error creating answer session:', error);
                    this.chatStore.state.interactions = [
                        ...(existingInteractions || []),
                        {
                            query: term,
                            response: 'Sorry, there was an error creating the answer session. Please try again later.',
                            status: TAnswerStatus.error,
                            latest: true,
                            sources: [],
                        },
                    ];
                    return;
                }
            }
            if (!this.answerSession) {
                console.error('Answer session was not created');
                return;
            }
            try {
                // Check existence of answerStream method (means that the client is Orama Core)
                if (this.answerSession.answer) {
                    this.askOramaCore(term, relatedQueries);
                }
                else {
                    this.askOramaCloud(term);
                }
            }
            catch (error) {
                // Update chat store to show error to user
                const latestInteraction = this.chatStore.state.interactions[this.chatStore.state.interactions.length - 1];
                if (latestInteraction) {
                    latestInteraction.status = TAnswerStatus.error;
                    latestInteraction.response = 'Sorry, the answer service is not available. Please try again later.';
                    this.chatStore.state.interactions = [...this.chatStore.state.interactions];
                }
            }
        };
        this.askOramaCore = (query, relatedQueries) => {
            console.log('askOramaCore', query, relatedQueries);
            const streamParams = Object.assign({ query }, (relatedQueries
                ? {
                    related: {
                        enabled: true,
                        size: relatedQueries,
                        format: 'query',
                    },
                }
                : {}));
            const answerStream = this.answerSession.answerStream(streamParams);
            const processAsyncGenerator = async () => {
                var _a, e_1, _b, _c;
                try {
                    for (var _d = true, answerStream_1 = __asyncValues(answerStream), answerStream_1_1; answerStream_1_1 = await answerStream_1.next(), _a = answerStream_1_1.done, !_a; _d = true) {
                        _c = answerStream_1_1.value;
                        _d = false;
                        const _ = _c;
                    }
                }
                catch (e_1_1) {
                    e_1 = { error: e_1_1 };
                }
                finally {
                    try {
                        if (!_d && !_a && (_b = answerStream_1.return))
                            await _b.call(answerStream_1);
                    }
                    finally {
                        if (e_1)
                            throw e_1.error;
                    }
                }
            };
            processAsyncGenerator();
        };
        this.askOramaCloud = (term) => {
            const askParams = {
                term: term,
                limit: 10,
                threshold: 0.5,
            };
            const oldAnswerSession = this.answerSession;
            oldAnswerSession.ask(askParams);
        };
        this.abortAnswer = () => {
            if (!this.answerSession) {
                throw new OramaClientNotInitializedError();
            }
            if (this.answerSession.abort) {
                ;
                this.answerSession.abort();
            }
            else {
                ;
                this.answerSession.abortAnswer();
            }
        };
        this.regenerateLatest = async () => {
            if (!this.answerSession) {
                throw new OramaClientNotInitializedError();
            }
            // Check if the client is Orama Cloud
            if (this.answerSession.regenerateLast) {
                const nonOramaCoreAnswerSession = this.answerSession;
                nonOramaCoreAnswerSession.regenerateLast({ stream: false });
            }
            else {
                const oramaCoreAnswerSession = this.answerSession;
                oramaCoreAnswerSession.regenerateLast({ stream: false });
            }
        };
        this.resetChat = async () => {
            if (!this.answerSession) {
                throw new OramaClientNotInitializedError();
            }
            if (this.chatStore.state.interactions.length < 1) {
                return;
            }
            // TODO: SDK should abort any streaming before cleaning the sessions. It is not doing that today
            if (['loading', 'rendering', 'streaming'].includes(this.chatStore.state.interactions[this.chatStore.state.interactions.length - 1].status)) {
                this.abortAnswer();
            }
            this.answerSession.clearSession();
            this.chatStore.state.interactions = [];
        };
        this.client = oramaCoreClient ? oramaCoreClient : new Switch(oramaClient);
        this.chatStore = chatStore;
    }
    getResultMapValue(sourceMapKey, sourceMapObject, rawSource) {
        const sourcesMapFunctionOrString = sourceMapObject === null || sourceMapObject === void 0 ? void 0 : sourceMapObject[sourceMapKey];
        if (!sourcesMapFunctionOrString) {
            return undefined;
        }
        if (typeof sourcesMapFunctionOrString === 'function') {
            const sourcesMapFunction = sourcesMapFunctionOrString;
            return sourcesMapFunction(rawSource.document, rawSource.index_id);
        }
        const resultMapString = sourceMapObject[sourceMapKey];
        return rawSource.document[resultMapString];
    }
}
//# sourceMappingURL=ChatService.js.map
