var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { OramaClientNotInitializedError } from "../erros/OramaClientNotInitializ";
import { Switch } from "@orama/switch";
const LIMIT_RESULTS = 10;
export class SearchService {
    constructor(oramaClient, oramaCoreClient, searchStore) {
        this.search = async (term, selectedFacet, callbacks) => {
            var _a, _b, _c, _d;
            if (!this.client) {
                throw new OramaClientNotInitializedError();
            }
            this.abortSearch();
            if (!term) {
                this.searchStore.state.results = [];
                this.searchStore.state.count = 0;
                this.searchStore.state.facets = [];
                this.searchStore.state.highlightedIndex = -1;
                return;
            }
            this.searchStore.state.loading = true;
            const latestAbortController = this.abortController;
            const _e = (_a = this.searchStore.state.searchParams) !== null && _a !== void 0 ? _a : {}, { limit, offset, where } = _e, restSearchParams = __rest(_e, ["limit", "offset", "where"]);
            const clientSearchParams = Object.assign(Object.assign(Object.assign(Object.assign({}, restSearchParams), { term, limit: limit || LIMIT_RESULTS }), (where ? { where } : {})), (this.searchStore.state.facetProperty && Object.assign({ facets: {
                    [this.searchStore.state.facetProperty]: {},
                } }, (selectedFacet &&
                selectedFacet !== 'All' && {
                where: Object.assign({ [this.searchStore.state.facetProperty]: {
                        eq: selectedFacet,
                    } }, where),
            }))));
            try {
                const results = await this.client.search(clientSearchParams);
                if (latestAbortController.signal.aborted) {
                    return;
                }
                if (results && !results.hits) {
                    throw new Error('This search was made by a OramaClient with property mergeResult set to false. Orama Search Service requires mergeResult to be true.');
                }
                // biome-ignore lint/suspicious/noExplicitAny: To be fixed when Orama Swtich export the right type
                this.searchStore.state.results = this.parserResults(results === null || results === void 0 ? void 0 : results.hits, this.searchStore.state.resultMap);
                this.searchStore.state.count = (results === null || results === void 0 ? void 0 : results.count) || 0;
                this.searchStore.state.facets = this.parseFacets(results === null || results === void 0 ? void 0 : results.facets, this.searchStore.state.facetProperty);
                this.searchStore.state.highlightedIndex = -1;
                this.searchStore.state.loading = false;
                (_b = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onSearchCompletedCallback) === null || _b === void 0 ? void 0 : _b.call(callbacks, {
                    clientSearchParams,
                    result: {
                        results: this.searchStore.state.results,
                        resultsCount: this.searchStore.state.count,
                        facets: this.searchStore.state.facets,
                    },
                });
                (_c = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onSearchCompletedCallback) === null || _c === void 0 ? void 0 : _c.call(callbacks, {
                    clientSearchParams,
                    result: {
                        results: this.searchStore.state.results,
                        resultsCount: this.searchStore.state.count,
                        facets: this.searchStore.state.facets,
                    },
                });
            }
            catch (error) {
                console.error('Search error:', error);
                if (latestAbortController.signal.aborted) {
                    return;
                }
                this.searchStore.state.loading = false;
                (_d = callbacks === null || callbacks === void 0 ? void 0 : callbacks.onSearchErrorCallback) === null || _d === void 0 ? void 0 : _d.call(callbacks, error);
            }
        };
        // TODO
        this.retry = () => {
            throw new Error('Not implemented');
        };
        this.getResultMapObjectByForTheHit = (resultMapArrayOrObject, hit) => {
            const resultMapArray = Array.isArray(resultMapArrayOrObject) ? resultMapArrayOrObject : [resultMapArrayOrObject];
            // If there is only one result map, assume it's the one for all hits, regardless of datasourceId
            if (resultMapArray.length === 1) {
                return resultMapArray[0];
            }
            // TODO: Instead of doing it per each HIT, we may want to create a map of datasourceId -> resultMap to avoid the O(n) lookup
            const resultmapMatch = resultMapArray.find((resultMap) => resultMap.datasourceId === hit.datasource_id);
            return resultmapMatch || {};
        };
        this.parserResults = (hits, resultMapArrayOrObject) => {
            if (!hits) {
                return [];
            }
            const perSectionResults = [];
            const arraySectionMap = {};
            for (const hit of hits) {
                const resultMap = this.getResultMapObjectByForTheHit(resultMapArrayOrObject, hit);
                const searchResultWithScore = this.hitToSearchResultParser(hit, resultMap);
                const documentSectionValue = typeof resultMap.section === 'function'
                    ? resultMap.section(hit.document, hit.datasource_id)
                    : hit.document[resultMap.section];
                if (arraySectionMap[documentSectionValue] === undefined) {
                    perSectionResults.push({
                        section: documentSectionValue,
                        items: [searchResultWithScore],
                    });
                    arraySectionMap[documentSectionValue] = perSectionResults.length - 1;
                }
                else {
                    const sectionIndex = arraySectionMap[documentSectionValue];
                    perSectionResults[sectionIndex].items.push(searchResultWithScore);
                }
            }
            return perSectionResults;
        };
        this.hitToSearchResultParser = (hit, resultMapObject) => {
            function getResultMapValue(resultMapKey) {
                const resultMapFunctionOrString = resultMapObject[resultMapKey];
                if (!resultMapFunctionOrString) {
                    return hit.document[resultMapKey];
                }
                if (typeof resultMapFunctionOrString === 'function') {
                    const resultMapFunction = resultMapFunctionOrString;
                    return resultMapFunction(hit.document, hit.datasource_id);
                }
                const resultMapString = resultMapObject[resultMapKey];
                return hit.document[resultMapString];
            }
            function getIcon() {
                const iconStringOrFunction = resultMapObject.icon;
                if (!iconStringOrFunction) {
                    return null;
                }
                if (typeof iconStringOrFunction === 'function') {
                    const iconFunctionRender = iconStringOrFunction;
                    const iconFunctionRenderResult = iconFunctionRender(hit.document, hit.datasource_id);
                    return iconFunctionRenderResult !== null && iconFunctionRenderResult !== void 0 ? iconFunctionRenderResult : null;
                }
                return resultMapObject.icon;
            }
            return {
                id: hit.id,
                title: getResultMapValue('title'),
                description: getResultMapValue('description'),
                path: getResultMapValue('path'),
                icon: getIcon(),
            };
        };
        this.parseFacets = (rawFacets, facetProperty) => {
            // Handle case where facets are missing or empty
            if (!facetProperty || !rawFacets) {
                return [];
            }
            // Handle different facet formats based on client type
            const facetPropertyObject = rawFacets[facetProperty];
            if (!facetPropertyObject || !facetPropertyObject.values) {
                return [];
            }
            // Process facets in standard format
            const totalCount = Object.values(facetPropertyObject.values).reduce((acc, count) => acc + count, 0);
            const allFacets = Object.keys(facetPropertyObject.values).map((key) => {
                return {
                    name: key,
                    count: facetPropertyObject.values[key],
                };
            });
            allFacets.unshift({ name: 'All', count: totalCount });
            return allFacets;
        };
        this.client = oramaCoreClient ? oramaCoreClient : new Switch(oramaClient);
        this.searchStore = searchStore;
        this.abortController = new AbortController();
    }
    abortSearch() {
        this.abortController.abort();
        this.abortController = new AbortController();
    }
}
//# sourceMappingURL=SearchService.js.map
