import { p as proxyCustomElement, H, h, d as Host } from './p-BGpMMtbT.js';
import './p-DXSoIv40.js';
import { g as generateRandomID, u as updateThemeClasses, a as updateCssVariables } from './p-BQsBOb3k.js';
import { g as getText } from './p-Db5sp_fc.js';
import { d as defineCustomElement$2 } from './p-B65Mn12l.js';

const oramaSearchButtonCss = ":host{display:block}.kyb-shortcut{background-color:#eee9f6;background-color:var(--background-color-tertiary,#eee9f6);border-radius:.5rem;border-radius:var(--radius-s,calc(8rem/var(--orama-base-font-size, 16)));padding:.25rem;padding:var(--spacing-xs,calc(4rem/var(--orama-base-font-size, 16))) var(--spacing-s,calc(4rem/var(--orama-base-font-size, 16)))}";

const OramaSearchButton$1 = /*@__PURE__*/ proxyCustomElement(class OramaSearchButton extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.size = 'medium';
        this.colorScheme = 'light';
        /**
         * Text dictionary for customizing all text content in the component.
         * This can be set either via HTML attribute as a JSON string or via JavaScript as an object.
         * @example
         * // Via HTML attribute
         * <orama-search-button dictionary='{"searchButtonLabel": "Search docs"}' />
         *
         * // Via JavaScript
         * const searchButton = document.querySelector('orama-search-button');
         * searchButton.dictionary = { searchButtonLabel: "Search docs" };
         */
        this.dictionary = {};
        this.systemScheme = 'light';
        this.shortcutLabel = '';
        this.componentID = generateRandomID('search-button');
        this.onPrefersColorSchemeChange = (event) => {
            this.systemScheme = event.matches ? 'dark' : 'light';
            this.updateTheme();
        };
    }
    /**
     * Watch for changes to the dictionary prop
     */
    handleTextDictionaryChange(newValue) {
        // Handle case where dictionary is passed as a string (via HTML attribute)
        if (typeof newValue === 'string') {
            try {
                this.dictionary = JSON.parse(newValue);
            }
            catch (e) {
                console.error('Error parsing dictionary:', e);
            }
        }
    }
    /**
     * Gets the text for a specific key from the dictionary prop.
     *
     * @param key - The key to get the text for
     * @returns The text for the specified key
     */
    getText(key) {
        return getText(key, this.dictionary);
    }
    watchHandler() {
        this.updateTheme();
    }
    handleSearchboxClosed(event) {
        // TODO: should be based on the id of current searchbox
        this.buttonRef.querySelector('button').focus();
    }
    // trigger click when entering  '⌘ K' o Mac or 'Ctrl + K'
    handleKeyDown(event) {
        if (event.key === 'k' && (event.metaKey || event.ctrlKey)) {
            event.preventDefault();
            this.buttonRef.click();
        }
    }
    updateTheme() {
        const scheme = updateThemeClasses(this.htmlElement, this.colorScheme, this.systemScheme);
        updateCssVariables(this.htmlElement, scheme, this.themeConfig);
    }
    handleShortcutLabel() {
        const userAgent = navigator.userAgent;
        const isMac = userAgent.includes('Mac');
        return isMac ? '⌘ K' : 'Ctrl + K';
    }
    connectedCallback() {
        this.htmlElement.id = this.componentID;
        this.shortcutLabel = this.handleShortcutLabel();
        this.schemaQuery = window.matchMedia('(prefers-color-scheme: dark)');
        this.systemScheme = this.schemaQuery.matches ? 'dark' : 'light';
        this.updateTheme();
        this.schemaQuery.addEventListener('change', this.onPrefersColorSchemeChange);
    }
    disconnectedCallback() {
        this.schemaQuery.removeEventListener('change', this.onPrefersColorSchemeChange);
    }
    componentWillLoad() {
        this.updateTheme();
    }
    render() {
        return (h(Host, { key: 'd784308be3ef8bb2abeaa25bed43f51962ec7586' }, h("orama-button", { key: '2dafcd15bb0b5f468e6a91d9651cec22f2670a61', type: "button", variant: "secondary", ref: (el) => (this.buttonRef = el), size: this.size, onClick: () => {
                const searchBoxList = document.getElementsByTagName('orama-search-box');
                if (!searchBoxList.length) {
                    console.error('No OramaSearchBox found');
                    return;
                }
                if (searchBoxList.length > 1) {
                    console.error('Multiple instances of OramaSearchBox (orama-search-box) found. Considere to assign an ID to OramaSearchBox, implement onClick on OramaSearchButton and select desired OramaSearchBox on onClick method');
                    return;
                }
                searchBoxList[0].open = true;
            } }, h("span", { key: 'c96898d75e57d546930794c25d04a6cd3cd3f960', slot: "adorment-start" }, h("ph-magnifying-glass", { key: 'a42c0d765c8bdf1647ebc7d9e85c8ce224397ddf' })), h("slot", { key: '979f16ad8739765dc42ed9cbb46d6b2eb789e000' }, this.getText('searchButtonLabel')), h("span", { key: 'e211d3ccd39bbe8b628569a4d69ff23c7a0a9935', slot: "adorment-end", class: "kyb-shortcut" }, this.shortcutLabel))));
    }
    get htmlElement() { return this; }
    static get watchers() { return {
        "dictionary": ["handleTextDictionaryChange"],
        "themeConfig": ["watchHandler"],
        "colorScheme": ["watchHandler"]
    }; }
    static get style() { return oramaSearchButtonCss; }
}, [1, "orama-search-button", {
        "size": [1],
        "themeConfig": [16, "theme-config"],
        "colorScheme": [1, "color-scheme"],
        "dictionary": [16],
        "systemScheme": [32],
        "shortcutLabel": [32],
        "componentID": [32]
    }, [[16, "searchboxClosed", "handleSearchboxClosed"], [4, "keydown", "handleKeyDown"]], {
        "dictionary": ["handleTextDictionaryChange"],
        "themeConfig": ["watchHandler"],
        "colorScheme": ["watchHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["orama-search-button", "orama-button"];
    components.forEach(tagName => { switch (tagName) {
        case "orama-search-button":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, OramaSearchButton$1);
            }
            break;
        case "orama-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const OramaSearchButton = OramaSearchButton$1;
const defineCustomElement = defineCustomElement$1;

export { OramaSearchButton, defineCustomElement };
//# sourceMappingURL=orama-search-button.js.map

//# sourceMappingURL=orama-search-button.js.map