import { p as proxyCustomElement, H, h, d as Host } from './p-BGpMMtbT.js';

const oramaTextareaCss = ".sc-orama-textarea-h{align-items:center;background:#fff;background:var(--background-color-secondary,#fff);border:1px solid #dadada;border:1px solid var(--border-color-primary,#dadada);border-radius:1rem;border-radius:var(--textarea-radius,var(--radius-l,calc(16rem/var(--orama-base-font-size, 16))));box-shadow:#fff;box-shadow:var(--textarea-shadow,var(--shadow-color-primary,#fff));display:flex;padding:.25rem .25rem .25rem .75rem;padding:var(--spacing-xs,calc(4rem/var(--orama-base-font-size, 16))) var(--spacing-xs,calc(4rem/var(--orama-base-font-size, 16))) var(--spacing-xs,calc(4rem/var(--orama-base-font-size, 16))) var(--spacing-m,calc(12rem/var(--orama-base-font-size, 16)));position:relative}.sc-orama-textarea-s>[slot=adornment-end]{align-items:center;display:flex;justify-content:center}.textarea.sc-orama-textarea{background:none;border:none;color:#151515;color:var(--text-color-primary,#151515);font-family:inherit;font-size:1rem;font-size:var(--font-size-md,calc(16rem/var(--orama-base-font-size, 16)));font-size:.875rem;font-size:var(--font-size-sm,calc(14rem/var(--orama-base-font-size, 16)));font-weight:400;font-weight:var(--font-weight-normal,400);left:0;line-height:1.5;line-height:var(--font-line-height-m,1.5);margin:0;outline:none;padding:0;resize:none;right:0;transition:height .1s;width:100%}@media (min-width:768.02px){.textarea.sc-orama-textarea{font-size:.875rem;font-size:var(--font-size-sm,calc(14rem/var(--orama-base-font-size, 16)));padding:.5rem 0;padding:var(--spacing-s,calc(8rem/var(--orama-base-font-size, 16))) 0}}.textarea.sc-orama-textarea::-moz-placeholder{color:#99989d;color:var(--text-color-inactive,#99989d);overflow:hidden;text-overflow:ellipsis;white-space:nowrap;width:95%}.textarea.sc-orama-textarea::placeholder{color:#99989d;color:var(--text-color-inactive,#99989d);overflow:hidden;text-overflow:ellipsis;white-space:nowrap;width:95%}.textarea.sc-orama-textarea:focus-visible{border-color:#432d77;border-color:var(--border-color-accent,#432d77);outline:none}.textarea.sc-orama-textarea::-webkit-scrollbar{width:.3em}.textarea.sc-orama-textarea::-webkit-scrollbar-track{background:transparent}.textarea.sc-orama-textarea::-webkit-scrollbar-thumb{background-color:hsla(0,0%,70%,.522);border-radius:1rem;border-radius:var(--border-radius-l,calc(16rem/var(--orama-base-font-size, 16)))}@media (min-width:768.02px){.textarea.sc-orama-textarea{font-size:1rem;font-size:var(--font-size-md,calc(16rem/var(--orama-base-font-size, 16)))}}";

const OramaTextarea = /*@__PURE__*/ proxyCustomElement(class OramaTextarea extends H {
    constructor() {
        super();
        this.__registerHost();
        this.value = '';
        this.minRows = 1;
        this.autoFocus = false;
        this.handleChange = (event) => {
            const target = event.target;
            if (!this.value) {
                this.syncHeight();
            }
            this.value = target.value;
        };
    }
    handleAutoFocusChange() {
        if (this.autoFocus) {
            this.textarea.focus();
        }
    }
    componetWillLoad() {
        this.startAdornmentWidth = this.getNamedSlotWidth('adornment-start');
        this.endAdornmentWidth = this.getNamedSlotWidth('adornment-end');
        this.syncHeight();
        if (this.autoFocus) {
            this.textarea.focus();
        }
    }
    getNamedSlotWidth(slotName) {
        const slot = this.el.querySelector(`slot[name="${slotName}"]`);
        if (slot) {
            const assignedElements = slot.assignedElements();
            if (assignedElements.length > 0) {
                const firstAssignedElement = assignedElements[0];
                const width = firstAssignedElement.offsetWidth;
                return width;
            }
        }
        return 0;
    }
    handlePropsChange() {
        this.syncHeight();
    }
    getStyleValue(value) {
        return Number.parseInt(value, 10) || 0;
    }
    calculateTextareaStyles() {
        const input = this.textarea;
        const computedStyle = window.getComputedStyle(input);
        if (computedStyle.width === '0px') {
            return {
                outerHeightStyle: 0,
                overflowing: false,
            };
        }
        const inputShallow = this.shadowTextarea;
        inputShallow.style.width = computedStyle.width;
        inputShallow.value = input.value || this.placeholder || 'x';
        if (inputShallow.value.slice(-1) === '\n') {
            inputShallow.value += ' ';
        }
        const boxSizing = computedStyle.boxSizing;
        const padding = this.getStyleValue(computedStyle.paddingBottom) + this.getStyleValue(computedStyle.paddingTop);
        const border = this.getStyleValue(computedStyle.borderBottomWidth) + this.getStyleValue(computedStyle.borderTopWidth);
        const innerHeight = inputShallow.scrollHeight;
        inputShallow.value = 'x';
        const singleRowHeight = inputShallow.scrollHeight;
        let outerHeight = innerHeight;
        if (this.minRows) {
            outerHeight = Math.max(Number(this.minRows) * singleRowHeight, outerHeight);
        }
        if (this.maxRows) {
            outerHeight = Math.min(Number(this.maxRows) * singleRowHeight, outerHeight);
        }
        outerHeight = Math.max(outerHeight, singleRowHeight);
        const outerHeightStyle = outerHeight + (boxSizing === 'border-box' ? padding + border : 0);
        const overflowing = Math.abs(outerHeight - innerHeight) <= 1;
        return { outerHeightStyle, overflowing };
    }
    syncHeight() {
        const textareaStyles = this.calculateTextareaStyles();
        if (!textareaStyles) {
            return;
        }
        const outerHeightStyle = textareaStyles.outerHeightStyle;
        if (this.height !== outerHeightStyle) {
            this.height = outerHeightStyle;
            this.textarea.style.height = `${outerHeightStyle}px`;
        }
        this.textarea.style.overflow = textareaStyles.overflowing ? 'hidden' : '';
    }
    getAllProps() {
        const props = {};
        for (let i = 0; i < this.el.attributes.length; i++) {
            const attr = this.el.attributes[i];
            props[attr.name] = attr.value;
        }
        return props;
    }
    render() {
        return (h(Host, { key: '5d11fb96304062ca9861694d682d8e12064bdb1e' }, h("slot", { key: '17fc62c00745e57cdc27e826f5481f4c6f497e3e', name: "adornment-start" }), h("textarea", Object.assign({ key: '016d07bebfb05aa4f547bffbc2afa3dfc88970bc' }, this.getAllProps(), { value: this.value, onInput: this.handleChange, ref: (el) => (this.textarea = el), rows: Number(this.minRows), style: {
                height: this.height ? `${this.height}px` : undefined,
                paddingLeft: this.startAdornmentWidth ? `${this.startAdornmentWidth}px` : undefined,
                paddingRight: this.endAdornmentWidth ? `${this.endAdornmentWidth}px` : undefined,
            }, class: "textarea", placeholder: this.placeholder })), h("slot", { key: '515eb08d900f216a6e1a70a45287750fb4eec53f', name: "adornment-end" }), h("textarea", { key: '76d4ec4a7a7ecae613a1dc47beec8716e652acab', "aria-hidden": "true", readonly: true, ref: (el) => (this.shadowTextarea = el), tabindex: -1, class: "textarea", style: {
                visibility: 'hidden',
                position: 'absolute',
                overflow: 'hidden',
                height: '0',
                top: '0',
                left: '0',
                transform: 'translateZ(0)',
                paddingTop: '0',
                paddingBottom: '0',
                paddingLeft: this.startAdornmentWidth ? `${this.startAdornmentWidth}px` : undefined,
                paddingRight: this.endAdornmentWidth ? `${this.endAdornmentWidth}px` : undefined,
            } })));
    }
    get el() { return this; }
    static get watchers() { return {
        "autoFocus": ["handleAutoFocusChange"],
        "value": ["handlePropsChange"],
        "maxRows": ["handlePropsChange"],
        "minRows": ["handlePropsChange"]
    }; }
    static get style() { return oramaTextareaCss; }
}, [6, "orama-textarea", {
        "value": [1],
        "maxRows": [8, "max-rows"],
        "minRows": [8, "min-rows"],
        "placeholder": [1],
        "autoFocus": [4, "auto-focus"],
        "height": [32],
        "startAdornmentWidth": [32],
        "endAdornmentWidth": [32]
    }, undefined, {
        "autoFocus": ["handleAutoFocusChange"],
        "value": ["handlePropsChange"],
        "maxRows": ["handlePropsChange"],
        "minRows": ["handlePropsChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["orama-textarea"];
    components.forEach(tagName => { switch (tagName) {
        case "orama-textarea":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, OramaTextarea);
            }
            break;
    } });
}

export { OramaTextarea as O, defineCustomElement as d };
//# sourceMappingURL=p-COgGb6VX.js.map

//# sourceMappingURL=p-COgGb6VX.js.map