import { type EventEmitter } from '../../../stencil-public-runtime';
import { type ChatMarkdownLinkHref, type ChatMarkdownLinkTarget, type ChatMarkdownLinkTitle, type OnAnswerGeneratedCallbackProps, type onStartConversationCallbackProps, type SearchResult, type SourcesMap, type Dictionary } from "../../../types/index";
import '@phosphor-icons/webcomponents/dist/icons/PhPaperPlaneTilt.mjs';
import '@phosphor-icons/webcomponents/dist/icons/PhStopCircle.mjs';
import '@phosphor-icons/webcomponents/dist/icons/PhArrowDown.mjs';
export declare class OramaChat {
    placeholder?: string;
    sourceBaseUrl?: string;
    linksTarget?: string;
    linksRel?: string;
    sourcesMap?: SourcesMap;
    showClearChat?: boolean;
    defaultTerm?: string;
    focusInput?: boolean;
    suggestions?: string[];
    relatedQueries?: number;
    prompt?: string;
    systemPrompts?: string[];
    clearChatOnDisconnect?: boolean;
    dictionary?: Partial<Dictionary>;
    disclaimer?: string;
    chatMarkdownLinkTitle?: ChatMarkdownLinkTitle;
    chatMarkdownLinkHref?: ChatMarkdownLinkHref;
    chatMarkdownLinkTarget?: ChatMarkdownLinkTarget;
    answerGenerated: EventEmitter<OnAnswerGeneratedCallbackProps>;
    clearChat: EventEmitter<void>;
    startConversation: EventEmitter<onStartConversationCallbackProps>;
    inputValue: string;
    showGoToBottomButton: boolean;
    handleSourceItemClick(event: CustomEvent<SearchResult>): void;
    handleDefaultTermChange(): void;
    focusInputWatcher(): void;
    promptWatcher(newValue: string, oldValue: string): void;
    handleTextDictionaryChange(): void;
    triggerSendQuestion: (question: string, relatedQueries?: number) => void;
    messagesContainerRef: HTMLElement;
    nonScrollableMessagesContainerRef: HTMLElement;
    textareaRef: HTMLOramaTextareaElement;
    isScrolling: boolean;
    prevScrollTop: number;
    scrollTarget: number;
    pendingNewInteractionSideEffects: boolean;
    scrollableContainerResizeObserver: ResizeObserver;
    nonScrollableContainerResizeObserver: ResizeObserver;
    lockScrollOnBottom: boolean;
    private chatStore;
    componentWillLoad(): void;
    /**
     * Gets the text for a specific key from the dictionary prop.
     * Prioritizes direct props (placeholder) for backward compatibility,
     * then falls back to the dictionary prop, and finally to the defaultTextDictionary.
     *
     * @param key - The key to get the text for
     * @returns The text for the specified key
     */
    getText(key: keyof Dictionary): string;
    handleFocus: () => void;
    calculateIsScrollOnBottom: () => boolean;
    scrollToBottom: (options?: {
        animated: boolean;
        onScrollDone?: () => void;
    }) => void;
    easeInOutQuad: (t: number) => number;
    recalculateGoBoToBottomButton: () => void;
    handleWheel: (e: WheelEvent) => void;
    setSources: () => void;
    componentDidLoad(): void;
    disconnectedCallback(): void;
    handleSubmit: (e: Event) => void;
    handleAbortAnswerClick: () => void;
    handleSuggestionClick: (suggestion: string, relatedQueries?: number) => void;
    handleClearChat: () => void;
    calculateIsContainerOverflowing: () => boolean;
    render(): any;
}
