import { type EventEmitter } from '../../stencil-public-runtime';
import type { ChatMarkdownLinkHref, ChatMarkdownLinkTarget, ChatMarkdownLinkTitle, CloudIndexConfig, ColorScheme, OnAnswerGeneratedCallbackProps, OnAnswerSourceClickCallbackProps, OnChatMarkdownLinkClickedCallbackProps, onStartConversationCallbackProps, SourcesMap, Dictionary } from "../../types/index";
import type { TThemeOverrides } from "../../config/theme";
import type { AnyOrama } from '@orama/orama';
import type { OramaClient } from '@oramacloud/client';
import type { CollectionManager } from '@orama/core';
import '@phosphor-icons/webcomponents/dist/icons/PhArrowClockwise.mjs';
export declare class ChatBox {
    htmlElement: HTMLElement;
    index?: CloudIndexConfig | CloudIndexConfig[];
    clientInstance?: OramaClient | AnyOrama;
    oramaCoreClientInstance?: CollectionManager;
    sourceBaseUrl?: string;
    linksTarget?: string;
    linksRel?: string;
    placeholder?: string;
    sourcesMap?: SourcesMap;
    suggestions?: string[];
    relatedQueries?: number;
    autoFocus: boolean;
    systemPrompts?: string[];
    prompt?: string;
    clearChatOnDisconnect: boolean;
    chatMarkdownLinkTitle?: ChatMarkdownLinkTitle;
    chatMarkdownLinkHref?: ChatMarkdownLinkHref;
    chatMarkdownLinkTarget?: ChatMarkdownLinkTarget;
    /**
     * Text dictionary for customizing all text content in the component.
     * This can be set either via HTML attribute as a JSON string or via JavaScript as an object.
     * It allows for customization of all text elements like placeholders, error messages, and UI labels.
     * @example
     * // Via HTML attribute
     * <orama-chat-box dictionary='{"chatPlaceholder": "Ask about our docs..."}' />
     *
     * // Via JavaScript
     * const chatBox = document.querySelector('orama-chat-box');
     * chatBox.dictionary = { chatPlaceholder: "Ask about our docs..." };
     */
    dictionary?: Partial<Dictionary>;
    disclaimer?: string;
    /**
     * Component theme customization
     */
    themeConfig?: Partial<TThemeOverrides>;
    /**
     * Component color schema
     */
    colorScheme?: ColorScheme;
    componentID: string;
    systemScheme: Omit<ColorScheme, 'system'>;
    schemaQuery: MediaQueryList;
    /**
     * Gets the text for a specific key from the dictionary prop.
     * Prioritizes direct props (placeholder) for backward compatibility,
     * then falls back to the dictionary prop, and finally to the defaultTextDictionary.
     *
     * @param key - The key to get the text forstartChatService
     * @returns The text for the specified key
     */
    getText(key: keyof Dictionary): string;
    /**
     * Fired when answer generation is successfully completed
     */
    answerGenerated: EventEmitter<OnAnswerGeneratedCallbackProps>;
    /**
     * Fired when the chat is cleared
     */
    clearChat: EventEmitter<void>;
    /**
     * Fired as soon as the conversation is started
     */
    startConversation: EventEmitter<onStartConversationCallbackProps>;
    /**
     * Fired when user clicks on answer source
     */
    answerSourceClick: EventEmitter<OnAnswerSourceClickCallbackProps>;
    /**
     * Fired when user clicks on chat markdown link
     */
    chatMarkdownLinkClicked: EventEmitter<OnChatMarkdownLinkClickedCallbackProps>;
    watchHandler(): void;
    /**
     * Watch for changes to the dictionary prop
     */
    handleTextDictionaryChange(newValue: Partial<Dictionary> | string): void;
    private chatStore;
    componentWillLoad(): void;
    componentDidLoad(): void;
    /**
     * Get the old Orama Client if oramaCore ins't available
     */
    getOldOramaClient(): AnyOrama | OramaClient<true>;
    private startChatService;
    updateTheme(): void;
    private onPrefersColorSchemeChange;
    connectedCallback(): void;
    disconnectedCallback(): void;
    render(): any;
}
