import type { ColorScheme, Dictionary } from "../../types/index";
import '@phosphor-icons/webcomponents/dist/icons/PhMagnifyingGlass.mjs';
import type { TThemeOverrides } from "../../components";
export type ButtonClick = {
    id: HTMLElement;
    searchboxId: string;
};
export declare class OramaSearchButton {
    htmlElement: HTMLElement;
    size: 'small' | 'medium' | 'large';
    themeConfig?: Partial<TThemeOverrides>;
    colorScheme?: ColorScheme;
    /**
     * Text dictionary for customizing all text content in the component.
     * This can be set either via HTML attribute as a JSON string or via JavaScript as an object.
     * @example
     * // Via HTML attribute
     * <orama-search-button dictionary='{"searchButtonLabel": "Search docs"}' />
     *
     * // Via JavaScript
     * const searchButton = document.querySelector('orama-search-button');
     * searchButton.dictionary = { searchButtonLabel: "Search docs" };
     */
    dictionary?: Partial<Dictionary>;
    /**
     * Watch for changes to the dictionary prop
     */
    handleTextDictionaryChange(newValue: Partial<Dictionary> | string): void;
    systemScheme: Omit<ColorScheme, 'system'>;
    shortcutLabel: string;
    componentID: string;
    schemaQuery: MediaQueryList;
    /**
     * Gets the text for a specific key from the dictionary prop.
     *
     * @param key - The key to get the text for
     * @returns The text for the specified key
     */
    getText(key: keyof Dictionary): string;
    watchHandler(): void;
    buttonRef: HTMLElement;
    handleSearchboxClosed(event: CustomEvent<ButtonClick>): void;
    handleKeyDown(event: KeyboardEvent): void;
    updateTheme(): void;
    private handleShortcutLabel;
    private onPrefersColorSchemeChange;
    connectedCallback(): void;
    disconnectedCallback(): void;
    componentWillLoad(): void;
    render(): any;
}
