import type { AnyOrama, Results, SearchParams } from '@orama/orama';
import type { ClientSearchParams } from '@oramacloud/client';
export type SearchResult = {
    id: string;
    title: string;
    description: string;
    path: string;
};
export type ColorScheme = 'dark' | 'light' | 'system';
export type SearchResultWithScore = SearchResult & {
    score: number;
};
export type SearchResultWithIcon = SearchResult & {
    icon: string;
};
export type SearchResultBySection = {
    section: string | undefined;
    items: SearchResultWithIcon[];
};
export type Facet = {
    name: string;
    count: number;
};
export type ResultMapKeys = keyof Omit<SearchResult, 'id'> | 'section' | 'datasourceId';
export type ResultMapRenderFunction = (item: any, datasourceId: string) => string;
export type ResultItemRenderFunction = (item: any, datasourceId: string) => string | null | undefined;
export type ResultMapItem = {
    [K in ResultMapKeys]?: string | ResultMapRenderFunction;
} & {
    icon?: string | ResultItemRenderFunction;
};
export type ResultMap = ResultMapItem | ResultMapItem[];
export type SourcesMapKeys = keyof Omit<SearchResult, 'id'>;
type NewType = (item: any, datasourceId: string) => string;
export type SourcesMapRenderFunction = NewType;
export type SourcesMapItem = {
    [K in SourcesMapKeys]?: string | SourcesMapRenderFunction;
} & {
    datasourceId?: string;
};
export type SourceItem = {
    title: string;
    description: string;
    path: string;
};
export type SourcesMap = SourcesMapItem | SourcesMapItem[];
export type CloudIndexConfig = {
    api_key: string;
    endpoint: string;
};
export type AskParams = SearchParams<AnyOrama> & {
    userData?: unknown;
    related?: {
        howMany?: 1 | 2 | 3 | 4 | 5;
        format?: 'question' | 'query';
    };
};
export type ChatMarkdownLinkTitle = ({ text, href }: {
    text: string;
    href: string;
}) => string;
export type ChatMarkdownLinkHref = ({ text, href }: {
    text: string;
    href: string;
}) => string;
export type ChatMarkdownLinkTarget = ({ text, href }: {
    text: string;
    href: string;
}) => string;
export type OnChatMarkdownLinkClickedCallbackProps = {
    text: string;
    href: string;
};
export type OnSearchCompletedCallbackProps = {
    clientSearchParams: ClientSearchParams;
    result: {
        results: SearchResultBySection[];
        resultsCount: number;
        facets: Facet[];
    };
};
export type OnSearchResultClickCallbackProps = {
    result: SearchResult;
};
export type OnAnswerGeneratedCallbackProps = {
    askParams: AskParams;
    query: string;
    sources: Results<unknown>;
    answer: string;
    segment: string | null;
    trigger: string | null;
};
export type onStartConversationCallbackProps = {
    userPrompt: string;
    systemPrompts: string[];
};
export type OnAnswerSourceClickCallbackProps = {
    source: SearchResult;
};
export declare enum TAnswerStatus {
    idle = "idle",
    loading = "loading",// waiting for sources to be fetched
    rendering = "rendering",// rendering interaction sources
    streaming = "streaming",// streaming interaction answer
    error = "error",
    aborted = "aborted",
    done = "done"
}
export type TSource = {
    title: string;
    description?: string;
    path: string;
};
export type TChatInteraction = {
    query: string;
    response?: string;
    sources?: SourceItem[];
    latest?: boolean;
    status: TAnswerStatus;
    interactionId?: string;
    relatedQueries?: string[];
};
/**
 * Dictionary for all text content in the components
 */
export type Dictionary = {
    searchPlaceholder: string;
    chatPlaceholder: string;
    noResultsFound: string;
    noResultsFoundFor: string;
    suggestions: string;
    seeAll: string;
    addMore: string;
    clearChat: string;
    errorMessage: string;
    disclaimer: string;
    startYourSearch: string;
    initErrorSearch: string;
    initErrorChat: string;
    chatButtonLabel: string;
    searchButtonLabel: string;
};
export {};
